/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2020 All Rights Reserved.
 */

package com.abssqr.plat.biz.api.ast;

import com.abssqr.plat.biz.support.ServiceSupport;
import com.abssqr.plat.common.dal.mysql.auto.paging.AstPackPagePage;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.LoanPackRelSummary;
import com.abssqr.plat.common.facade.enums.AstScreenRuleTypeEnum;
import com.abssqr.plat.common.facade.param.ast.AstPackOprParam;
import com.abssqr.plat.common.facade.param.ast.AstPackQryParam;
import com.abssqr.plat.common.facade.param.ast.AstPackSealOprParam;
import com.abssqr.plat.common.facade.param.ast.AstPackSplitPackOprParam;
import com.abssqr.plat.common.facade.param.ast.AstPackUnPackOprParam;
import com.abssqr.plat.common.facade.result.BasePage;
import com.abssqr.plat.common.facade.result.pack.AstPackListVO;
import com.abssqr.plat.common.facade.result.pack.AstPackVO;
import com.abssqr.plat.common.facade.service.ast.AstPackService;
import com.abssqr.plat.common.facade.validation.Valid;
import com.abssqr.plat.common.model.convertor.vo.AstPackListVOConvert;
import com.abssqr.plat.common.model.convertor.web.AstPackWebConvert;
import com.abssqr.plat.common.model.domain.ast.AstPack;
import com.abssqr.plat.common.model.repo.ast.AstPackRepo;
import com.abssqr.plat.common.model.repo.ast.LoanPackRelRepo;
import com.abssqr.plat.core.service.ast.AstPackManager;

import com.general.system.common.util.VarChecker;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author xiachenxiang
 * @version com.abssqr.plat.biz.api.ast: AstPackServiceImpl.java, v 0.1 2020-04-18 3:13 PM xiachenxiang Exp $
 */
@Service
public class AstPackServiceImpl extends ServiceSupport implements AstPackService {
    @Autowired
    AstPackManager  astPackManager;
    @Autowired
    AstPackRepo     astPackRepo;
    @Autowired
    LoanPackRelRepo loanPackRelRepo;
    @Override
    public String edit(@Valid AstPackOprParam param) {
        VarChecker.checkNotNull(param);
        if (CollectionUtils.isNotEmpty(param.getScreenRuleList())) {
            param.getScreenRuleList().forEach(astScreenRuleParam -> {
                if (astScreenRuleParam.getLeftCondition() != null) {
                    VarChecker.checkNotEmpty(astScreenRuleParam.getLeftValue(), "{0}左条件存在，必须填值",
                        AstScreenRuleTypeEnum.getByCode(astScreenRuleParam.getRuleType()).getDesc());
                }
                if (astScreenRuleParam.getRightCondition() != null) {
                    VarChecker.checkNotEmpty(astScreenRuleParam.getRightValue(), "{0}右条件存在，必须填值",
                        AstScreenRuleTypeEnum.getByCode(astScreenRuleParam.getRuleType()).getDesc());
                }
            });
        }
        return this.doOpr(param, () -> astPackManager.add(AstPackWebConvert.param2Model(param)));
    }

    @Override
    public BasePage<AstPackListVO> getList(@Valid AstPackQryParam param) {
        return this.doQry(param, () -> {
            AstPackPagePage page = astPackRepo.getList(param);
            BasePage<AstPackListVO> result = new BasePage<AstPackListVO>();
            result.setCurrPageNo(page.getCurrPageNo());
            result.setTotal(page.getTotal());
            result.setLimit(page.getLimit());
            result.setDatas(AstPackListVOConvert.convert2VOList(page.getDatas()));
            return result;
        });
    }

    @Override
    public AstPackVO get(AstPackQryParam astPackQryParam) {
        VarChecker.checkNotEmpty(astPackQryParam.getPackNo(), "资产包编号必填");
        AstPack astPack = astPackManager.get(astPackQryParam.getPackNo());
        AstPackVO result  = AstPackWebConvert.model2VO(astPack);
        if(astPack!=null) {
            LoanPackRelSummary summary = loanPackRelRepo.sumAstPack(astPack.getPackNo());
            result.setAstCnt(summary.getAstCnt());
            result.setAstPrinBal(summary.getAstPrinBal());
        }
        return result;
    }

    @Override
    public String sealPack(@Valid AstPackSealOprParam astPackSealOprParam) {
        return this.doOpr(astPackSealOprParam, () -> {
            astPackManager.sealPack(astPackSealOprParam.getPackNo(),astPackSealOprParam.getSealPackDate());
            return astPackSealOprParam.getBizNo();
        });
    }

    @Override
    public String unPack(@Valid AstPackUnPackOprParam astPackUnPackOprParam) {
        return this.doOpr(astPackUnPackOprParam, () -> {
            astPackManager.unPack(astPackUnPackOprParam.getPackNo());
            return astPackUnPackOprParam.getBizNo();
        });
    }

    /**
     * 拆包
     *
     * @param astPackSplitPackOprParam
     * @return
     */
    @Override
    public String splitPack(AstPackSplitPackOprParam astPackSplitPackOprParam) {
        return this.doOpr(astPackSplitPackOprParam, () -> {
            astPackManager.splitPack(astPackSplitPackOprParam.getPackNo());
            return astPackSplitPackOprParam.getBizNo();
        });
    }

}
