/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2017 All Rights Reserved.
 */
package com.abssqr.plat.biz.validate.validator;

import com.abssqr.plat.biz.validate.AFieldValidator;
import com.abssqr.plat.biz.validate.FieldError;
import com.abssqr.plat.biz.validate.ValidateService;
import com.abssqr.plat.common.facade.validation.VldDate;
import com.general.system.common.util.SystemDateUtil;

import java.util.Date;

/**
 * 注解@{@link VldDate}的校验类实现
 *
 * @author zhenxuan.luo
 * @version $Id: DtValidator.java, v 0.1 2015年5月19日 上午11:29:42 zhenxuan.luo Exp $
 */
public final class DateValidator extends AFieldValidator<VldDate> {
    
    /**
     * 默认构造函数
     * @return
     */
    public DateValidator() {
        super(VldDate.class);
    }
    
    /**
     * @param annotationClass
     */
    public DateValidator(Class<VldDate> annotationClass) {
        super(annotationClass);
    }
    
    /**
     *
     * @param validateService 对象校验器
     * @param annotationObj 校验注解对象
     * @param validTargetFieldObj 需要校验的字段对象
     * @param errorConext 每个字段错误的存储类
     * @return
     */
    @Override
    protected boolean isValid(ValidateService validateService, VldDate annotationObj,
                              Object validTargetFieldObj, FieldError errorConext) {
        boolean isValid = false;
        try {
            return isValid = validate(annotationObj, validTargetFieldObj);
        } finally {
            if (!isValid) {
                errorConext.setErrorMsg(errorConext.getErrorMsg() + annotationObj.message());
            }
        }
    }
    
    private boolean validate(VldDate annotationObj, Object validTargetFieldObj) {
        
        if (validTargetFieldObj == null) {
            return (annotationObj.nullable()) ? true : false;
        }
        
        if (validTargetFieldObj instanceof Date) {
            Date date = (Date) validTargetFieldObj;
            
            if (annotationObj.isFuture()) {
                return date.after(SystemDateUtil.getSystemDate());
            } else {
                return true;
            }
        }
        return false;
    }
    
}
