/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2017 All Rights Reserved.
 */
package com.abssqr.plat.biz.validate.validator;

import com.abssqr.plat.biz.validate.AFieldValidator;
import com.abssqr.plat.biz.validate.FieldError;
import com.abssqr.plat.biz.validate.ValidateService;
import com.abssqr.plat.common.facade.validation.VldEnums;
import com.general.system.common.util.LogUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.lang.reflect.Method;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 注解@{@link VldEnums}的校验类实现
 * @author zhenxuan.luo
 * @version $Id: EnumsValidator.java, v 0.1 2015年5月19日 上午10:58:17 zhenxuan.luo Exp $
 */
public final class EnumsValidator extends AFieldValidator<VldEnums> {
    private final static Logger                            LOGGER      = LoggerFactory.getLogger(
            EnumsValidator.class);
    /** Method的cache */
    private final        ConcurrentHashMap<String, Method> methodCache = new ConcurrentHashMap<String, Method>();
    
    /**
     * 默认构造器
     */
    public EnumsValidator() {
        super(VldEnums.class);
    }
    
    @Override
    public boolean isValid(ValidateService validateService, VldEnums annotationObj,
                           Object validTargetFieldObj, FieldError errorConext) {
        boolean isValid = false;
        try {
            return isValid = validate(annotationObj, validTargetFieldObj);
        } finally {
            if (!isValid) {
                errorConext.setErrorMsg(annotationObj.message());
            }
        }
    }
    
    /**
     * 校验
     * @param annotationObj 校验注解对象
     * @param validTargetFieldObj 需要校验的字段对象
     * @return true:校验通过,反之返回false
     */
    @SuppressWarnings("rawtypes")
    private boolean validate(VldEnums annotationObj, Object validTargetFieldObj) {
        if (validTargetFieldObj == null) {
            return (annotationObj.nullable()) ? true : false;
        }
    
        if (validTargetFieldObj instanceof String) {
            String enumCode = (String) validTargetFieldObj;
            if (StringUtils.isBlank(enumCode)) {
                return (annotationObj.nullable()) ? true : false;
            }
            
            Class<? extends Enum> enumClass = annotationObj.enumClass();
            String methodName = annotationObj.getByMethod();
            try {
                Method method = getMethod(enumClass, methodName);
    
                Enum result = (Enum) method.invoke(null, enumCode);
    
                if (result != null && result.getClass() == enumClass) {
                    return true;
                }
            } catch (Throwable e) {
                LogUtil.error(LOGGER, e, "EnumsValidator:校验失败" + annotationObj + ":" + validTargetFieldObj);
                return false;
            }
        }
        return false;
    }
    
    /**
     *
     * @param enumClass
     * @param methodName
     * @return 方法对象, 如果Method找不到会抛出异常
     * @throws NoSuchMethodException
     * @throws SecurityException
     */
    @SuppressWarnings("rawtypes")
    private Method getMethod(Class<? extends Enum> enumClass,
                             String methodName) throws SecurityException, NoSuchMethodException {
        String key = enumClass.getName() + methodName;
        Method cacheData = methodCache.get(key);
        if (cacheData != null) {
            return cacheData;
        }
        Method method = enumClass.getMethod(methodName, String.class);
        methodCache.put(key, method);
        return method;
    }
}
