/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2020 All Rights Reserved.
 */
package com.abssqr.plat.biz.shared.handler.impl;

import com.abssqr.plat.biz.shared.handler.CommonTaskHandler;
import com.abssqr.plat.common.facade.enums.AstPackStatusEnum;
import com.abssqr.plat.common.facade.enums.CommonTaskTypeEnum;
import com.abssqr.plat.common.model.domain.ast.AstPack;
import com.abssqr.plat.common.model.domain.ast.AstPoolEntity;
import com.abssqr.plat.common.model.domain.task.CommonTask;
import com.abssqr.plat.common.model.repo.ast.AstPackRepo;
import com.abssqr.plat.common.model.repo.astPool.AstPoolRepository;
import com.abssqr.plat.core.service.ast.AstPackManager;
import com.abssqr.plat.core.service.rule.AstScreenRuleComponent;

import com.general.system.common.util.LogUtil;
import com.general.system.common.util.VarChecker;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.support.TransactionTemplate;

/**
 * @author bangis.wangdf
 * @version com.abssqr.plat.biz.shared.handler: PackMatchTaskHandler.java, v 0.1 2020-04-26 11:58 bangis.wangdf Exp $
 */
public class PackMatchTaskHandler extends CommonTaskHandler {
    @Autowired
    AstPackRepo            astPackRepo;
    @Autowired
    AstPackManager         astPackManager;
    @Autowired
    AstPoolRepository      astPoolRepository;
    @Autowired
    TransactionTemplate    transactionTemplate;
    @Autowired
    AstScreenRuleComponent astScreenRuleComponent;

    @Override
    public CommonTask execute(CommonTask commonTask) {
        transactionTemplate.execute(status -> {
            //锁资产池
            AstPoolEntity astPoolEntity = astPoolRepository.lockAstPool(commonTask.getContext());
            VarChecker.checkNotNull(astPoolEntity,"找不到对应的资产池{0}",commonTask.getContext());

            //锁资产包
            AstPack astPack = astPackManager.lockAstPack(commonTask.getBizNo());
            VarChecker.checkNotNull(astPack,"找不到对应的资产包{0}",commonTask.getBizNo());

            //状态判断
            if(AstPackStatusEnum.INIT==astPack.getStatus()){
                //开始筛选
                //TODO SQL 预演完成，待合同字段明确后补充
                int cnt = astScreenRuleComponent.screenAst(astPack);
                if(cnt==0){
                    LogUtil.warn(LOGGER,"资产包[{0}],未筛选到资产",astPack.getPackNo());
                }
                //筛选完成，更新资产包状态
                astPackRepo.screenFisPack(astPack.getPackNo());
            }else{
                LogUtil.warn(LOGGER,"资产包[{0}],状态为[{1}],无需筛选",astPack.getPackNo(),astPack.getStatus());
            }
            return status;
        });
        return commonTask;
    }

    @Override
    protected CommonTaskTypeEnum commonTaskType() {
        return CommonTaskTypeEnum.PACK_MATCH;
    }
}
