/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2018 All Rights Reserved. 
 */
package com.abssqr.plat.common.dal.interceptor;

import com.abssqr.plat.common.util.constants.LogConstants;
import com.abssqr.plat.common.util.interceptor.AbstractInterceptor;
import com.abssqr.plat.common.util.loggers.DigestLoggers;
import com.abssqr.plat.common.util.loggers.LogInfo;
import com.general.system.common.model.exception.BaseException;
import com.general.system.common.util.LogUtil;
import org.aopalliance.intercept.MethodInvocation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.lang.reflect.Method;
import java.util.Collection;
import java.util.Map;

/**
 *
 * @author zhenxuan.luo
 * @version com.loan.biz.service.inteceptor: BizServiceInterceptor.java, v 0.1 2018-12-19 AM11:38 zhenxuan.luo Exp $ 
 */
@Component
public class DalInterceptor extends AbstractInterceptor {
    
    /** logger */
    private static final Logger LOGGER = LoggerFactory.getLogger(DalInterceptor.class);
    
    private final static Logger DAL_DIGEST = DigestLoggers.DAL_DIGEST;
    
    @Override
    public Object businessInvoke(MethodInvocation invocation) throws Throwable {
        Object result = null;
        Throwable ex = null;
        // 初始化调用者信息
        LogInfo logInfo = initDigestLogCallerInfo(invocation);
        
        try {
            // 确保租户id,zoneUid设置到上下文中
            result = invocation.proceed();
        } catch (BaseException e) {
            ex = e;
            throw e;
            //result = InterceptorUtil.processError(LOGGER, invocation, e.getMessage(), e);
        } catch (Throwable e) {
            ex = e;
            throw e;
            // result = InterceptorUtil.processError(LOGGER, invocation, e);
        } finally {
            // 打印业务摘要日志
            logBizDigest(logInfo, result, ex);
        }
        return result;
    }
    
    /**
     * 构建调用方基础信息
     *
     * @param invocation
     */
    private LogInfo initDigestLogCallerInfo(MethodInvocation invocation) {
        
        //设置日志摘要信息
        LogInfo logInfo = new LogInfo();
        
        Method method = invocation.getMethod();
        logInfo.setFacadeName(method.getDeclaringClass().getSimpleName());
        logInfo.setMethodName(method.getName());
        
        return logInfo;
    }
    
    /**
     * 构建操作类型的摘要日志
     *
     * @param logInfo
     * @param obj
     * @param throwable
     */
    private void logBizDigest(LogInfo logInfo, Object obj, Throwable throwable) {
        
        try {
            //1.1 构建开始标志
            StringBuilder sb = new StringBuilder(400);
            sb.append(LogConstants.FMT_BEGIN);
            
            sb.append(logInfo.getFacadeName()).append(LogConstants.DOT);
            sb.append(logInfo.getMethodName()).append(LogConstants.COMMA);
            sb.append(throwable == null ? LogConstants.YES : LogConstants.NO).append(LogConstants.COMMA);
            sb.append(logInfo.getElapseTime()).append(LogConstants.MS);
            
            sb.append(LogConstants.FMT_MIDDLE);
            
            if (obj == null) {
                sb.append(LogConstants.NONE);
            } else {
                sb.append(obj.getClass().getSimpleName());
                if (obj instanceof Collection<?>) {
                    sb.append(LogConstants.COMMA).append(((Collection<?>) obj).size());
                } else if (obj instanceof Map<?, ?>) {
                    sb.append(LogConstants.COMMA).append(((Map<?, ?>) obj).size());
                } else if (isPrimitive(obj.getClass())) {
                    sb.append(LogConstants.COMMA).append(obj);
                }
            }
            
            sb.append(LogConstants.FMT_END);
            sb.append(LogConstants.FMT_BEGIN);
            sb.append(LogUtil.getSign());
            sb.append(LogConstants.FMT_END);
            //2 写入摘要日志文件
            if (DAL_DIGEST.isInfoEnabled()) {
                DAL_DIGEST.info(sb.toString());
            }
            
        } catch (Throwable e) {
            LOGGER.error("打印摘要日志异常", e);
        }
    }
}