package com.abssqr.plat.common.dal.mysql.auto.dao;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import java.util.ArrayList;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.AccountDO;
import java.util.List;
import com.abssqr.plat.common.dal.mysql.auto.mapper.AccountDOMapper;

/**
* The Table abs_account.
* 账户
*/
@Repository
public class AccountDAO{

    @Autowired
    private AccountDOMapper accountDOMapper;

    /**
     * desc:插入表:abs_account.<br/>
     * @param entity entity
     * @return int
     */
    
    public int insert(AccountDO entity){
        return accountDOMapper.insert(entity);
    }
    /**
     * desc:批量插入表:abs_account.<br/>
     * @param list list
     * @return int
     */
    
    public int insertBatch(List<AccountDO> list){
        accountDOMapper.insertBatch(list);
        return  list.size(); 
    }
    /**
     * desc:根据主键删除数据:abs_account.<br/>
     * @param id id
     * @return int
     */
    
    public int deleteById(Long id){
        return accountDOMapper.deleteById(id);
    }
    /**
     * desc:根据主键获取数据:abs_account.<br/>
     * @param id id
     * @return AccountDO
     */
    
    public AccountDO getById(Long id){
        return accountDOMapper.getById(id);
    }
    /**
     * desc:getByAccountNo.<br/>
     * @param actNo actNo
     * @return AccountDO
     */
    
    public AccountDO getByAccountNo(String actNo){
        return accountDOMapper.getByAccountNo(actNo);
    }
    /**
     * desc:根据EntityCode删除数据:abs_account.<br/>
     * @param actType actType
     * @param entityCode entityCode
     * @return int
     */
    
    public int deleteByEntityCodeAndActType(String actType,String entityCode){
        return accountDOMapper.deleteByEntityCodeAndActType(actType, entityCode);
    }
    /**
     * desc:根据机构实体获取账号.<br/>
     * @param actAttr actAttr
     * @param entityCode entityCode
     * @param list list
     * @return List<AccountDO>
     */
    
    public List<AccountDO> selectByEntityCodeAndActType(String actAttr,String entityCode,List<String> list){
    if(list!=null && list.size()>201){throw new RuntimeException("list 超出201长度限制");}
        return accountDOMapper.selectByEntityCodeAndActType(actAttr, entityCode, list);
    }
    /**
     * desc:根据机构实体获取账号.<br/>
     * @param actType actType
     * @param entityCode entityCode
     * @return List<AccountDO>
     */
    
    public List<AccountDO> selectByEntityCodeAndType(String actType,String entityCode){
        return accountDOMapper.selectByEntityCodeAndType(actType, entityCode);
    }
    /**
     * desc:根据机构编号删除账号.<br/>
     * @param entityCode entityCode
     * @return int
     */
    
    public int deleteByEntityCode(String entityCode){
        return accountDOMapper.deleteByEntityCode(entityCode);
    }
}
