package com.abssqr.plat.common.dal.mysql.auto.dao;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import java.util.ArrayList;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.LoanBakDO;
import java.util.List;
import java.util.Date;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.PropDisbStat;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.PropCntStat;
import com.abssqr.plat.common.dal.mysql.auto.paging.LoanBakListPage;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.LoanBakFormationItem;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.LoanBakReportStat;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.AstScale;
import com.abssqr.plat.common.dal.mysql.auto.mapper.LoanBakDOMapper;

/**
* The Table abs_loan_bak.
* 信贷资产
*/
@Repository
public class LoanBakDAO{

    @Autowired
    private LoanBakDOMapper loanBakDOMapper;

    /**
     * desc:批量插入表:abs_loan_bak.<br/>
     * @param list list
     * @return int
     */
    
    public int insertBatch(List<LoanBakDO> list){
        loanBakDOMapper.insertBatch(list);
        return  list.size(); 
    }
    /**
     * desc:根据主键获取数据:abs_loan_instal_log.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return PropDisbStat
     */
    
    public PropDisbStat statDisb(Date accountDate,String planNo){
        return loanBakDOMapper.statDisb(accountDate, planNo);
    }
    /**
     * desc:statPlanBal.<br/>
     * @param accountDate accountDate
     * @param ownOrg ownOrg
     * @return PropCntStat
     */
    
    public PropCntStat statPlanBal(Date accountDate,String ownOrg){
        return loanBakDOMapper.statPlanBal(accountDate, ownOrg);
    }
    /**
     * desc:根据主键获取数据:abs_loan_instal_log.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<PropCntStat>
     */
    
    public List<PropCntStat> statLocation(Date accountDate,String planNo){
        return loanBakDOMapper.statLocation(accountDate, planNo);
    }
    /**
     * desc:根据主键获取数据:ABS_LOAN_BAK.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<PropCntStat>
     */
    
    public List<PropCntStat> statAge(Date accountDate,String planNo){
        return loanBakDOMapper.statAge(accountDate, planNo);
    }
    /**
     * desc:根据主键获取数据:ABS_LOAN_BAK.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<PropCntStat>
     */
    
    public List<PropCntStat> statGender(Date accountDate,String planNo){
        return loanBakDOMapper.statGender(accountDate, planNo);
    }
    /**
     * desc:getPageByOwnOrg.<br/>
     * @param loanBakList loanBakList
     * @return LoanBakListPage
     */
    
    public LoanBakListPage getPageByOwnOrg(LoanBakListPage loanBakList){
        int total = loanBakDOMapper.getPageByOwnOrgCount(loanBakList);
        if(total>0){
            loanBakList.setDatas(loanBakDOMapper.getPageByOwnOrgResult(loanBakList));
        }else{
            loanBakList.setDatas(new ArrayList());
        }
        loanBakList.setTotal(total);
        return loanBakList;
    }
    /**
     * desc:统计资产当前剩余分期数量及余额总计.<br/>
     * @param accountDate accountDate
     * @param ownOrg ownOrg
     * @return List<LoanBakFormationItem>
     */
    
    public List<LoanBakFormationItem> queryAstFormation(Date accountDate,String ownOrg){
        return loanBakDOMapper.queryAstFormation(accountDate, ownOrg);
    }
    /**
     * desc:统计资产产品分期及余额总计.<br/>
     * @param accountDate accountDate
     * @param ownOrg ownOrg
     * @return List<LoanBakFormationItem>
     */
    
    public List<LoanBakFormationItem> queryProdFormation(Date accountDate,String ownOrg){
        return loanBakDOMapper.queryProdFormation(accountDate, ownOrg);
    }
    /**
     * desc:资产余额状态统计代替statBal.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<LoanBakReportStat>
     */
    
    public List<LoanBakReportStat> statLoanBakStatus(Date accountDate,String planNo){
        return loanBakDOMapper.statLoanBakStatus(accountDate, planNo);
    }
    /**
     * desc:五级分类统计代替statBal.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<LoanBakReportStat>
     */
    
    public List<LoanBakReportStat> statLoanBakClz(Date accountDate,String planNo){
        return loanBakDOMapper.statLoanBakClz(accountDate, planNo);
    }
    /**
     * desc:91逾期未核销统计代替statBal.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @param statVal statVal
     * @param statType statType
     * @param wtfStatus wtfStatus
     * @param ovdDays ovdDays
     * @return List<LoanBakReportStat>
     */
    
    public List<LoanBakReportStat> statLoanBakOvdWtf(Date accountDate,String planNo,String statVal,String statType,String wtfStatus,Integer ovdDays){
        return loanBakDOMapper.statLoanBakOvdWtf(accountDate, planNo, statVal, statType, wtfStatus, ovdDays);
    }
    /**
     * desc:ovd_day天数统计代替statBal.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<LoanBakReportStat>
     */
    
    public List<LoanBakReportStat> statLoanBakOvdDays(Date accountDate,String planNo){
        return loanBakDOMapper.statLoanBakOvdDays(accountDate, planNo);
    }
    /**
     * desc:统计当日新增资产年化收益.<br/>
     * @param inDate inDate
     * @param disbDate disbDate
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<LoanBakReportStat>
     */
    
    public List<LoanBakReportStat> statLoanBakProfit(Date inDate,Date disbDate,Date accountDate,String planNo){
        return loanBakDOMapper.statLoanBakProfit(inDate, disbDate, accountDate, planNo);
    }
    /**
     * desc:获取资产规模.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<AstScale>
     */
    
    public List<AstScale> getAstScale(Date accountDate,String planNo){
        return loanBakDOMapper.getAstScale(accountDate, planNo);
    }
}
