package com.abssqr.plat.common.dal.mysql.auto.mapper;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.PlanReportItemDO;
import java.util.List;
import java.util.Date;
import org.apache.ibatis.annotations.Param;

/**
 * 由于需要对分页支持,请直接使用对应的DAO类
 * The Table abs_plan_report_item.
 * ABS_PLAN_REPORT_ITEM
 */
public interface PlanReportItemDOMapper{

    /**
     * desc:批量插入表:abs_plan_report_item.<br/>
     * @param list list
     * @return int
     */
    int insertBatch(List<PlanReportItemDO> list);
    /**
     * desc:根据唯一约束AbsPlanReportItem获取数据:abs_plan_report_item.<br/>
     * @param rptNo rptNo
     * @param planNo planNo
     * @return List<PlanReportItemDO>
     */
    List<PlanReportItemDO> getByRpt(@Param("rptNo")String rptNo,@Param("planNo")String planNo);
    /**
     * desc:根据主键获取数据:abs_plan_report.<br/>
     * @param endDate endDate
     * @param startDate startDate
     * @param planNo planNo
     * @return List<PlanReportItemDO>
     */
    List<PlanReportItemDO> getByDate(@Param("endDate")Date endDate,@Param("startDate")Date startDate,@Param("planNo")String planNo);
    /**
     * desc:根据计划和日期获取单项统计值.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @param rptItem rptItem
     * @return PlanReportItemDO
     */
    PlanReportItemDO getOneRptItemByPlanNoAndAccDate(@Param("accountDate")Date accountDate,@Param("planNo")String planNo,@Param("rptItem")String rptItem);
    /**
     * desc:根据计划和日期获取多个统计项的汇总值.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @param list list
     * @return List<PlanReportItemDO>
     */
    List<PlanReportItemDO> queryRptItemsByPlanNoAndAccDate(@Param("accountDate")Date accountDate,@Param("planNo")String planNo,@Param("list")List<String> list);
    /**
     * desc:根据计划和日期区间获取多个统计项的汇总值.<br/>
     * @param endDate endDate
     * @param startDate startDate
     * @param planNo planNo
     * @param list list
     * @return List<PlanReportItemDO>
     */
    List<PlanReportItemDO> queryPlanRptItemsByPlanNoSection(@Param("endDate")Date endDate,@Param("startDate")Date startDate,@Param("planNo")String planNo,@Param("list")List<String> list);
    /**
     * desc:根据计划和日期区间获取多个统计项的每日数据.<br/>
     * @param endDate endDate
     * @param startDate startDate
     * @param listItem listItem
     * @param listPlanNo listPlanNo
     * @return List<PlanReportItemDO>
     */
    List<PlanReportItemDO> queryDayRptItemsByPlanNoSection(@Param("endDate")Date endDate,@Param("startDate")Date startDate,@Param("listItem")List<String> listItem,@Param("listPlanNo")List<String> listPlanNo);
    /**
     * desc:根据计划和日期区间获取最小日期.<br/>
     * @param endDate endDate
     * @param startDate startDate
     * @param planNo planNo
     * @param list list
     * @return Date
     */
    Date queryPlanReportMinDateByPlanNoSection(@Param("endDate")Date endDate,@Param("startDate")Date startDate,@Param("planNo")String planNo,@Param("list")List<String> list);
}
