package com.abssqr.plat.common.dal.mysql.auto.mapper;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.TrTaskDO;
import java.util.List;
import java.util.Date;
import java.lang.Long;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.TransferFailTaskStat;
import org.apache.ibatis.annotations.Param;

/**
 * 由于需要对分页支持,请直接使用对应的DAO类
 * The Table ABS_TR_TASK.
 * 转让任务
 */
public interface TrTaskDOMapper{

    /**
     * desc:插入表:ABS_TR_TASK.<br/>
     * @param entity entity
     * @return int
     */
    int insert(TrTaskDO entity);
    /**
     * desc:批量插入表:ABS_TR_TASK.<br/>
     * @param list list
     * @return int
     */
    int insertBatch(List<TrTaskDO> list);
    /**
     * desc:根据主键删除数据:ABS_TR_TASK.<br/>
     * @param id id
     * @return int
     */
    int deleteById(Long id);
    /**
     * desc:根据主键获取数据:ABS_TR_TASK.<br/>
     * @param id id
     * @return TrTaskDO
     */
    TrTaskDO getById(Long id);
    /**
     * desc:获取初始化状态的任务.<br/>
     * @param curTime curTime
     * @param limit limit
     * @param batchNo batchNo
     * @param packType packType
     * @return List<TrTaskDO>
     */
    List<TrTaskDO> selectInitTask(@Param("curTime")Date curTime,@Param("limit")Long limit,@Param("batchNo")String batchNo,@Param("packType")String packType);
    /**
     * desc:根据主键对数据加锁：ABS_TR_TASK.<br/>
     * @param id id
     * @return TrTaskDO
     */
    TrTaskDO lockByIdNowait(Long id);
    /**
     * desc:更新执行的任务状态.<br/>
     * @param taskId taskId
     * @param memo memo
     * @param finishStatus finishStatus
     * @return int
     */
    int updateTaskStatus(@Param("taskId")Long taskId,@Param("memo")String memo,@Param("finishStatus")String finishStatus);
    /**
     * desc:筛选完成后将此批次数据重置为初始化状态.<br/>
     * @param batchNo batchNo
     * @param taskStatus taskStatus
     * @param oldTaskStatus oldTaskStatus
     * @return int
     */
    int updateBatchTaskStatus(@Param("batchNo")String batchNo,@Param("taskStatus")String taskStatus,@Param("oldTaskStatus")String oldTaskStatus);
    /**
     * desc:更新任务为执行中.<br/>
     * @param lastExecTime lastExecTime
     * @param lastHost lastHost
     * @param tasks tasks
     * @return int
     */
    int updateTaskExec(@Param("lastExecTime")Date lastExecTime,@Param("lastHost")String lastHost,@Param("tasks")List<TrTaskDO> tasks);
    /**
     * desc:重置状态，更新下次执行时间.<br/>
     * @param nextExecTime nextExecTime
     * @param taskId taskId
     * @param memo memo
     * @return int
     */
    int updateTaskExep(@Param("nextExecTime")Date nextExecTime,@Param("taskId")Long taskId,@Param("memo")String memo);
    /**
     * desc:根据ip重置任务.<br/>
     * @param lastHost lastHost
     * @param packType packType
     * @return int
     */
    int updateHangTasksByIp(@Param("lastHost")String lastHost,@Param("packType")String packType);
    /**
     * desc:查看转让任务是否都处理完.<br/>
     * @param batchNo batchNo
     * @return Long
     */
    Long cntInitTaskByBatchNo(@Param("batchNo")String batchNo);
    /**
     * desc:查询执行次数超次数的转让任务.<br/>
     * @param syncDate syncDate
     * @param execTimes execTimes
     * @param list list
     * @return List<TransferFailTaskStat>
     */
    List<TransferFailTaskStat> queryFailTRTask(@Param("syncDate")Date syncDate,@Param("execTimes")Long execTimes,@Param("list")List<String> list);
    /**
     * desc:查询执行次数超次数的转让任务数量.<br/>
     * @param syncDate syncDate
     * @param execTimes execTimes
     * @param packType packType
     * @return Long
     */
    Long countFailTrTask(@Param("syncDate")Date syncDate,@Param("execTimes")Long execTimes,@Param("packType")String packType);
    /**
     * desc:清理历史数据.<br/>
     * @param tfrDate tfrDate
     * @param tfrOut tfrOut
     * @param packType packType
     * @return int
     */
    int deleteHisTask(@Param("tfrDate")Date tfrDate,@Param("tfrOut")String tfrOut,@Param("packType")String packType);
    /**
     * desc:清理历史数据.<br/>
     * @param tfrOut tfrOut
     * @param packType packType
     * @return int
     */
    int deleteUnSuccTask(@Param("tfrOut")String tfrOut,@Param("packType")String packType);
    /**
     * desc:获取任务数量.<br/>
     * @param tfrOut tfrOut
     * @param packType packType
     * @param statusList statusList
     * @return Long
     */
    Long cntTrTaskByTfrOut(@Param("tfrOut")String tfrOut,@Param("packType")String packType,@Param("statusList")List<String> statusList);
}
