/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2017 All Rights Reserved. 
 */
package com.abssqr.plat.common.facade.enums;

import com.general.system.common.model.IEnum;
import com.google.common.collect.Lists;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 资产状态枚举
 * @author zhenxuan.luo
 * @version com.abssqr.common.model.enums: AstStatusEnum.java, v 0.1 2017-12-05 下午16:04 zhenxuan.luo Exp $
 */
public enum LoanStatusEnum implements IEnum {
    
    NORMAL("nor", "正常"),
    
    OVERDUE("ovd", "逾期"),
    
    CLEAR("clr", "结清"),
    
    REVERSE("rev", "冲正"),
    
    CANCEL("cal", "撤销"),
    ;
    
    private static final Map<String, LoanStatusEnum> codeMap      = new HashMap<String, LoanStatusEnum>();
    private static final List<LoanStatusEnum>        activeStatus = Lists.newArrayList(NORMAL, OVERDUE);
    private static final List<LoanStatusEnum>        effectStatus = Lists.newArrayList(CLEAR, NORMAL, OVERDUE);
    
    static {
        for (LoanStatusEnum item : LoanStatusEnum.values()) {
            codeMap.put(item.getCode(), item);
        }
    }
    
    private String code;
    private String desc;
    
    LoanStatusEnum(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }
    
    public static LoanStatusEnum getByCode(String code) {
        return codeMap.get(code);
    }
    
    public static List<LoanStatusEnum> getActiveStatus() {
        return activeStatus;
    }
    
    @Override
    public String getCode() {
        return this.code;
    }
    
    @Override
    public String getDesc() {
        return this.desc;
    }
    
    public boolean isActive() {
        return activeStatus.contains(this);
    }
    
    public boolean isEffect() {
        return effectStatus.contains(this);
    }
}