/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.facade.result.ast;

import com.abssqr.plat.common.facade.enums.LoanAstStatusEnum;
import com.abssqr.plat.common.facade.enums.PriceTypeEnum;
import com.abssqr.plat.common.facade.result.PlanConst;
import com.alibaba.fastjson.annotation.JSONField;
import com.general.system.common.model.Money;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 分期归属机构资产
 * @author hanfei
 * @version $Id: LoanAstDetail.java, v 0.1 2019-12-12 6:33 PM hanfei Exp $
 */
public class LoanAstDetail {
    
    /**
     * 机构资产收益列表
     */
    private List<LoanAstProfitDetail> profitDetails = new ArrayList<>();
    
    /**
     * loanAstNo 机构资产编号.
     */
    private String                           loanAstNo;
    /**
     * astNo 资产编号.
     */
    private String                           astNo;
    /**
     * outAstNo 外部资产编号.
     */
    private String                           outAstNo;
    /**
     * ownOrg 所属机构.
     */
    private String                           ownOrg;
    /**
     * lenderOrgCode 放款机构.
     */
    private String                           lenderOrgCode;
    /**
     * termNo 期次编号.
     */
    private int                              termNo;
    /**
     * prinBal 本金余额.
     */
    private Money      prinBal     = new Money();
    /**
     * paidPrinAmt 已还本金.
     */
    private Money      paidPrinAmt = new Money();
    /**
     * costAmt 资产成本.
     */
    private Money      costAmt     = new Money();
    /**
     * astPrice 资产定价.
     */
    private BigDecimal astPrice    = BigDecimal.ZERO;
    /**
     * 资产定价比例 显示
     */
    private String astPriceDesc;
    /**
     * astPriceType 定价类型.
     */
    private PriceTypeEnum     astPriceType;
    /**
     * inRule 资产流入规则.
     */
    private String                           inRule;
    /**
     * inDate 资产流入日期.
     */
    @JSONField(format="yyyy-MM-dd")
    private Date              inDate;
    /**
     * astStatus 资产状态：  NOR：正常所属  CLR：已清偿（转出或还款）.
     */
    private LoanAstStatusEnum astStatus;
    /**
     * clearDate 清偿日期.
     */
    @JSONField(format="yyyy-MM-dd")
    private Date              clearDate;
    /**
     * clearDate 清偿日期.
     */
    @JSONField(format="yyyy-MM-dd")
    private Date              endDate;

    
    public void addProfit(LoanAstProfitDetail profitDetail){
        this.profitDetails.add(profitDetail);
    }
    
    /**
     * 总收益
     * @return
     */
    public Money getTotalIntrBal() {
        Money profit = new Money();
        for(LoanAstProfitDetail profitDetail : this.profitDetails){
            profit.addTo(profitDetail.getProfitAmt());
        }
        return profit;
    }
    
    public List<LoanAstProfitDetail> getProfitDetails() {
        return profitDetails;
    }
    
    public void setProfitDetails(List<LoanAstProfitDetail> profitDetails) {
        this.profitDetails = profitDetails;
    }
    
    public String getLoanAstNo() {
        return loanAstNo;
    }
    
    public void setLoanAstNo(String loanAstNo) {
        this.loanAstNo = loanAstNo;
    }
    
    public String getAstNo() {
        return astNo;
    }
    
    public void setAstNo(String astNo) {
        this.astNo = astNo;
    }
    
    public String getOutAstNo() {
        return outAstNo;
    }
    
    public void setOutAstNo(String outAstNo) {
        this.outAstNo = outAstNo;
    }
    
    public String getOwnOrg() {
        return ownOrg;
    }
    
    public String getOwnOrgName() {
        return PlanConst.getPlanName(ownOrg);
    }
    
    public void setOwnOrg(String ownOrg) {
        this.ownOrg = ownOrg;
    }
    
    public String getLenderOrgCode() {
        return lenderOrgCode;
    }
    
    public String getLenderOrgName() {
        return PlanConst.getPlanName(lenderOrgCode);
    }
    
    public void setLenderOrgCode(String lenderOrgCode) {
        this.lenderOrgCode = lenderOrgCode;
    }
    
    public int getTermNo() {
        return termNo;
    }
    
    public void setTermNo(int termNo) {
        this.termNo = termNo;
    }
    
    public Money getPrinBal() {
        return prinBal;
    }
    
    public void setPrinBal(Money prinBal) {
        this.prinBal = prinBal;
    }
    
    public Money getPaidPrinAmt() {
        return paidPrinAmt;
    }
    
    public void setPaidPrinAmt(Money paidPrinAmt) {
        this.paidPrinAmt = paidPrinAmt;
    }
    
    public Money getCostAmt() {
        return costAmt;
    }
    
    public void setCostAmt(Money costAmt) {
        this.costAmt = costAmt;
    }
    
    public BigDecimal getAstPrice() {
        return astPrice;
    }
    
    public void setAstPrice(BigDecimal astPrice) {
        this.astPrice = astPrice;
    }
    
    public PriceTypeEnum getAstPriceType() {
        return astPriceType;
    }
    
    public void setAstPriceType(PriceTypeEnum astPriceType) {
        this.astPriceType = astPriceType;
    }
    
    public Date getInDate() {
        return inDate;
    }
    
    public void setInDate(Date inDate) {
        this.inDate = inDate;
    }
    
    public LoanAstStatusEnum getAstStatus() {
        return astStatus;
    }
    
    public void setAstStatus(LoanAstStatusEnum astStatus) {
        this.astStatus = astStatus;
    }
    
    public Date getClearDate() {
        return clearDate;
    }
    
    public void setClearDate(Date clearDate) {
        this.clearDate = clearDate;
    }
    
    public String getInRule() {
        return inRule;
    }
    
    public void setInRule(String inRule) {
        this.inRule = inRule;
    }
    
    public String getAstPriceDesc() {
        return astPriceDesc;
    }
    
    public void setAstPriceDesc(String astPriceDesc) {
        this.astPriceDesc = astPriceDesc;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
}
