/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.facade.result.ast;

import com.abssqr.plat.common.facade.base.DebtMoney;
import com.abssqr.plat.common.facade.enums.LoanStatusEnum;
import com.alibaba.fastjson.annotation.JSONField;

import com.abssqr.plat.common.facade.enums.OwnStatusEnum;
import com.general.system.common.model.Money;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 分期
 * @author hanfei
 * @version $Id: LoanInstalDetail.java, v 0.1 2019-12-12 6:33 PM hanfei Exp $ 
 */
public class LoanInstalDetail {
    
    /**
     * 当前期次分配收益
     */
    private List<LoanAstDetail> loanAstDetails = new ArrayList<>();
    /**
     * 当前期次分摊收益列表
     */
    private List<LoanAstDetail> refAstDetails = new ArrayList<>();
    /**
     * 开始日期
     */
    @JSONField(format="yyyy-MM-dd")
    private Date startDate;
    /**
     * 结束日期
     */
    @JSONField(format="yyyy-MM-dd")
    private Date endDate;
    /**
     * 结清日期
     */
    @JSONField(format="yyyy-MM-dd")
    private Date clearDate;
//    /**
//     * 资产在当前所属机构形成时间（比如转入日）
//     */
//    private Date inDate;
//    /**
//     * 宽限期结束日期
//     */
//    private Date graceEndDate;
//    /**
//     * 放款日期
//     */
//    private Date disbDate;
    
    /**
     * 资产ID
     */
    private       String              astNo;
    /**
     * 外部传入的资产唯一编号
     */
    private       String              outAstNo;
    /**
     * 期次号
     */
    private       int                 termNo;
    /**
     * 余额
     */
    @JSONField(serialize = false)
    private DebtMoney bal         = new DebtMoney();
    /**
     * 已还金额
     */
    @JSONField(serialize = false)
    private DebtMoney paidAmt     = new DebtMoney();
    /**
     * 减免金额
     */
    @JSONField(serialize = false)
    private DebtMoney rmtAmt      = new DebtMoney();
    /**
     * 五矿实收已还金额
     */
    @JSONField(serialize = false)
    private DebtMoney paidFundAmt = new DebtMoney();
    /**
     * 分期状态
     */
    private LoanStatusEnum status;
    /**
     * 资产归属状态
     */
    private OwnStatusEnum ownStatus;
    /**
     * 逾期天数
     */
    private int           ovdDays;
    
    /**
     * 本金余额
     */
    public Money getPrinBal(){
        Money bal = new Money();
        bal.addTo(this.bal.getAllPrin());
        return bal;
    }
    /**
     * 利息
     */
    public Money getIntrBal(){
        Money bal = new Money();
        bal.addTo(this.bal.getAllIntr());
        return bal;
    }
    /**
     * 罚息
     */
    public Money getPenalBal(){
        Money bal = new Money();
        bal.addTo(this.bal.getAllPenal());
        return bal;
    }
    /**
     * 费用
     */
    public Money getFeeBal(){
        Money bal = new Money();
        bal.addTo(this.bal.getAllIntAndFeeWithoutPenal().subtract(this.bal.getAllIntr()));
        return bal;
    }
    
    /**
     * 本金已还
     */
    public Money getPrinPaid(){
        Money bal = new Money();
        bal.addTo(this.paidAmt.getAllPrin());
        return bal;
    }
    /**
     * 利息已还
     */
    public Money getIntrPaid(){
        Money bal = new Money();
        bal.addTo(this.paidAmt.getAllIntr());
        return bal;
    }
    /**
     * 罚息已还
     */
    public Money getPenalPaid(){
        Money bal = new Money();
        bal.addTo(this.paidAmt.getAllPenal());
        return bal;
    }
    /**
     * 费用已还
     */
    public Money getFeePaid(){
        Money bal = new Money();
        bal.addTo(this.paidAmt.getAllIntAndFeeWithoutPenal().subtract(this.paidAmt.getAllIntr()));
        return bal;
    }
    
    /**
     * 减免总额
     * @return
     */
    public Money getRmtAll(){
        Money bal = new Money();
        bal.addTo(this.rmtAmt.getSum());
        return bal;
    }
    
    public List<LoanAstDetail> getLoanAstDetails() {
        return loanAstDetails;
    }
    
    public void setLoanAstDetails(List<LoanAstDetail> loanAstDetails) {
        this.loanAstDetails = loanAstDetails;
    }
    
    public Date getStartDate() {
        return startDate;
    }
    
    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    
    public Date getEndDate() {
        return endDate;
    }
    
    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    
    public Date getClearDate() {
        return clearDate;
    }
    
    public void setClearDate(Date clearDate) {
        this.clearDate = clearDate;
    }
    
    public String getAstNo() {
        return astNo;
    }
    
    public void setAstNo(String astNo) {
        this.astNo = astNo;
    }
    
    public String getOutAstNo() {
        return outAstNo;
    }
    
    public void setOutAstNo(String outAstNo) {
        this.outAstNo = outAstNo;
    }
    
    public int getTermNo() {
        return termNo;
    }
    
    public void setTermNo(int termNo) {
        this.termNo = termNo;
    }
    
    public DebtMoney getBal() {
        return bal;
    }
    
    public void setBal(DebtMoney bal) {
        this.bal = bal;
    }
    
    public DebtMoney getPaidAmt() {
        return paidAmt;
    }
    
    public void setPaidAmt(DebtMoney paidAmt) {
        this.paidAmt = paidAmt;
    }
    
    public DebtMoney getRmtAmt() {
        return rmtAmt;
    }
    
    public void setRmtAmt(DebtMoney rmtAmt) {
        this.rmtAmt = rmtAmt;
    }
    
    public DebtMoney getPaidFundAmt() {
        return paidFundAmt;
    }
    
    public void setPaidFundAmt(DebtMoney paidFundAmt) {
        this.paidFundAmt = paidFundAmt;
    }
    
    public LoanStatusEnum getStatus() {
        return status;
    }
    
    public void setStatus(LoanStatusEnum status) {
        this.status = status;
    }
    
    public int getOvdDays() {
        return ovdDays;
    }
    
    public void setOvdDays(int ovdDays) {
        this.ovdDays = ovdDays;
    }
    
    public List<LoanAstDetail> getRefAstDetails() {
        return refAstDetails;
    }
    
    public void setRefAstDetails(List<LoanAstDetail> refAstDetails) {
        this.refAstDetails = refAstDetails;
    }

    public OwnStatusEnum getOwnStatus() {
        return ownStatus;
    }

    public void setOwnStatus(OwnStatusEnum ownStatus) {
        this.ownStatus = ownStatus;
    }
}
