/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2018 All Rights Reserved.
 */

package com.abssqr.plat.common.model.convertor;

import java.util.List;
import java.util.Optional;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.AstScreenRuleDO;
import com.abssqr.plat.common.facade.enums.AstScRuleLeftCondEnum;
import com.abssqr.plat.common.facade.enums.AstScRuleRightCondEnum;
import com.abssqr.plat.common.facade.enums.AstScreenRelTypeEnum;
import com.abssqr.plat.common.facade.enums.AstScreenRuleTypeEnum;
import com.abssqr.plat.common.facade.model.rule.AstScreenRule;

import com.general.system.common.util.VarChecker;
import com.google.common.collect.Lists;
import org.apache.commons.collections.CollectionUtils;

/**
 * @author yaphet
 * @version com.abssqr.plat.common.model.convertor: AstScreenRuleConvert.java, v 0.1 2018-03-29 上午11:52 yaphet Exp $
 */
public class AstScreenRuleConvert {

    public static List<AstScreenRuleDO> convert2DOList(List<AstScreenRule> param) {

        List<AstScreenRuleDO> result = Lists.newArrayList();
        if (CollectionUtils.isNotEmpty(param)) {
            param.forEach(item -> {
                if(item.isEffect()) {
                    result.add(convert2DO(item));
                }
            });
        }
        return result;
    }

    public static AstScreenRuleDO convert2DO(AstScreenRule param) {
        if (param == null) {
            return null;
        }
        AstScreenRuleDO result = new AstScreenRuleDO();
        //param 转 pack时已经转，这里做强制不能为空校验
        VarChecker.checkNotEmpty(param.getRelNo());
        VarChecker.checkNotNull(param.getRelType());
        //relNo 关联编号
        result.setRelNo(param.getRelNo());
        //relType 关联类型 1.资产打包 PACK
        result.setRelType(Optional.ofNullable(param.getRelType()).map(AstScreenRelTypeEnum::getCode).orElse(null));
        //ruleType 规则类型
        result.setRuleType(Optional.ofNullable(param.getRuleType()).map(AstScreenRuleTypeEnum::getCode).orElse(null));
        //leftValue 左值
        result.setLeftValue(param.getLeftValue());
        //rightValue 右值
        result.setRightValue(param.getRightValue());
        //leftCondition 左条件: 1.大于 GT 2.大于等于 GE
        result.setLeftCondition(Optional.ofNullable(param.getLeftCondition()).map(AstScRuleLeftCondEnum::getCode)
            .orElse(null));
        //rightCondition 右条件: 1.小于 LT 2.小于等于 LE 3.等于 EQ 4.包含 IN
        result.setRightCondition(Optional.ofNullable(param.getRightCondition()).map(AstScRuleRightCondEnum::getCode)
            .orElse(null));

        return result;
    }

    public static List<AstScreenRule> convert2ModelList(List<AstScreenRuleDO> params) {
        List<AstScreenRule> result = Lists.newArrayList();
        if (CollectionUtils.isNotEmpty(params)) {
            params.forEach(astScreenRuleDO -> {
                result.add(convert2Modes(astScreenRuleDO));
            });
        }
        return result;
    }

    public static AstScreenRule convert2Modes(AstScreenRuleDO param) {
        if (param == null) {
            return null;
        }
        AstScreenRule result = new AstScreenRule();
        //relNo 关联编号
        result.setRelNo(param.getRelNo());
        //relType 关联类型 1.资产打包 PACK
        result.setRelType(AstScreenRelTypeEnum.getByCode(param.getRelType()));
        //ruleType 规则类型
        result.setRuleType(AstScreenRuleTypeEnum.getByCode(param.getRuleType()));
        //leftValue 左值
        result.setLeftValue(param.getLeftValue());
        //rightValue 右值
        result.setRightValue(param.getRightValue());
        //leftCondition 左条件: 1.大于 GT 2.大于等于 GE
        result.setLeftCondition(AstScRuleLeftCondEnum.getByCode(param.getLeftCondition()));
        //rightCondition 右条件: 1.小于 LT 2.小于等于 LE 3.等于 EQ 4.包含 IN
        result.setRightCondition(AstScRuleRightCondEnum.getByCode(param.getRightCondition()));
        return result;
    }
}
