/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2018 All Rights Reserved.
 */

package com.abssqr.plat.common.model.convertor;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.LoanInstalLogDO;
import com.abssqr.plat.common.facade.base.DebtMoney;
import com.abssqr.plat.common.facade.base.OrgDistPftMoney;
import com.abssqr.plat.common.facade.enums.DebtMoneyFieldEnum;
import com.abssqr.plat.common.facade.enums.EventCodeEnum;
import com.abssqr.plat.common.facade.enums.LoanStatusEnum;
import com.abssqr.plat.common.model.domain.loanTrans.LoanInstalLog;
import com.general.system.common.model.Money;

/**
 * 账单分期明细与测算模块的还款计划模型互相转换
 *
 * @author yaphet
 * @version com.abssqr.plat.common.model.convertor: LoanInstalConvert.java, v 0.1 2018-06-20 上午10:53 yaphet Exp $
 */
public class LoanInstalLogConvert {
    
    public static LoanInstalLog convert2Domain(LoanInstalLogDO var) {
        
        if (null == var) {
            return null;
        }
    
        LoanInstalLog instance = new LoanInstalLog();
        instance.setUserId(var.getUserId());
        instance.setExecTms(var.getExecTms());
        instance.setAstNo(var.getAstNo());
        instance.setOutAstNo(var.getOutAstNo());
        instance.setOutBizNo(var.getOutBizNo());
        instance.setBizNo(var.getBizNo());
        instance.setSeqNo(var.getSeqNo());
        instance.setLenderOrgCode(var.getLenderOrgCode());
        instance.setManagerOrgCode(var.getManagerOrgCode());
        instance.setSponserOrgCode(var.getSponserOrgCode());
        instance.setOwnOrg(var.getOwnOrg());
        instance.setOwnPack(var.getOwnPack());
        instance.setProdNo(var.getProdNo());
        instance.setOutProdNo(var.getOutProdNo());
        instance.setContractNo(var.getContractNo());
        instance.setBfStatus(LoanStatusEnum.getByCode(var.getBfStatus()));
        instance.setAfStatus(LoanStatusEnum.getByCode(var.getAfStatus()));
        instance.setEventCode(EventCodeEnum.getByCode(var.getEventCode()));
        instance.setBfOvdDays(var.getBfOvdDays());
        instance.setAfOvdDays(var.getAfOvdDays());
        instance.setTransTime(var.getTransTime());
        instance.setAccountDate(var.getAccountDate());
        instance.setClrgAmt(var.getClrgAmt());
        instance.setAmt(createAmt(var));
        instance.setAfBal(createBal(var));
        instance.setTermNo(var.getTermNo());
        instance.setHangIntrAmt(var.getHangIntrAmt());
        instance.setPaidFundAmt(createPaidFundAmt(var));
        instance.setPaidHangIntrFundAmt(var.getPaidHangIntrFundAmt());
        instance.setOrgDistPftAmt(createOrgDistPftAmt(var));
        return instance;
        
    }

    /**
     * 处理机构分润
     * @param var
     * @return
     */
    private static OrgDistPftMoney createOrgDistPftAmt(LoanInstalLogDO var) {
        return new OrgDistPftMoney(var.getOrgDistPftAmt(),var.getOrgDistPftApporAmt(),var.getOrgDistPftPaidAmt());
    }

    public static LoanInstalLogDO convert2Do(LoanInstalLog var) {
        
        if (null == var) {
            return null;
        }
    
        LoanInstalLogDO instance = new LoanInstalLogDO();
        instance.setUserId(var.getUserId());
    
        instance.setExecTms(var.getExecTms());
        instance.setAstNo(var.getAstNo());
        instance.setOutAstNo(var.getOutAstNo());
        instance.setOutBizNo(var.getOutBizNo());
        instance.setBizNo(var.getBizNo());
        instance.setSeqNo(var.getSeqNo());
        instance.setLenderOrgCode(var.getLenderOrgCode());
        instance.setManagerOrgCode(var.getManagerOrgCode());
        instance.setSponserOrgCode(var.getSponserOrgCode());
        instance.setOwnOrg(var.getOwnOrg());
        instance.setOwnPack(var.getOwnPack());
        instance.setProdNo(var.getProdNo());
        instance.setOutProdNo(var.getOutProdNo());
        instance.setContractNo(var.getContractNo());
        instance.setBfStatus(var.getBfStatus().getCode());
        instance.setAfStatus(var.getAfStatus().getCode());
        instance.setEventCode(var.getEventCode().getCode());
        instance.setTransCode(var.getEventCode().getSceneCode().getCode());
        instance.setBfOvdDays(var.getBfOvdDays());
        instance.setAfOvdDays(var.getAfOvdDays());
        instance.setTermNo(var.getTermNo());
        instance.setTransTime(var.getTransTime());
        instance.setAccountDate(var.getAccountDate());
        instance.setClrgAmt(var.getClrgAmt());
        
        instance.setPrinAmt(var.getAmt().getByFieldType(DebtMoneyFieldEnum.PRIN));
        instance.setIntrAmt(var.getAmt().getByFieldType(DebtMoneyFieldEnum.INTR));
        instance.setPrinPenalAmt(var.getAmt().getByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY));
        instance.setIntrPenalAmt(var.getAmt().getByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY));
        instance.setFeeAmt(var.getAmt().getByFieldType(DebtMoneyFieldEnum.FEE));
        instance.setFeePenalAmt(var.getAmt().getByFieldType(DebtMoneyFieldEnum.FEE_PNY));
        instance.setOtherFeeAmt(var.getAmt().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE));
        
        instance.setAfPrinBal(var.getAfBal().getByFieldType(DebtMoneyFieldEnum.PRIN));
        instance.setAfIntrBal(var.getAfBal().getByFieldType(DebtMoneyFieldEnum.INTR));
        instance.setAfPrinPenalBal(var.getAfBal().getByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY));
        instance.setAfIntrPenalBal(var.getAfBal().getByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY));
        instance.setAfFeeBal(var.getAfBal().getByFieldType(DebtMoneyFieldEnum.FEE));
        instance.setAfFeePenalBal(var.getAfBal().getByFieldType(DebtMoneyFieldEnum.FEE_PNY));
        instance.setAfOtherFeeBal(var.getAfBal().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE));

        instance.setPaidPrinFundAmt(var.getPaidFundAmt().getByFieldType(DebtMoneyFieldEnum.PRIN));
        instance.setPaidPrinPenalFundAmt(var.getPaidFundAmt().getByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY));
        instance.setPaidIntrFundAmt(var.getPaidFundAmt().getByFieldType(DebtMoneyFieldEnum.INTR));
        instance.setPaidIntrPenalFundAmt(var.getPaidFundAmt().getByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY));
        instance.setPaidFeeFundAmt(var.getPaidFundAmt().getByFieldType(DebtMoneyFieldEnum.FEE));
        instance.setPaidFeePenalFundAmt(var.getPaidFundAmt().getByFieldType(DebtMoneyFieldEnum.FEE_PNY));
        instance.setPaidOtherFeeFundAmt(var.getPaidFundAmt().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE));
        
        instance.setHangIntrAmt(var.getHangIntrAmt());
        instance.setPaidHangIntrFundAmt(var.getPaidHangIntrFundAmt());
        instance.setOrgDistPftAmt(var.getOrgDistPftAmt().getAmt());
        instance.setOrgDistPftApporAmt(var.getOrgDistPftAmt().getApporAmt());
        instance.setOrgDistPftPaidAmt(var.getOrgDistPftAmt().getPaidAmt());
        return instance;
        
    }
    
    private static DebtMoney createBal(LoanInstalLogDO var) {
        DebtMoney debtMoney = new DebtMoney();
        debtMoney.setByFieldType(DebtMoneyFieldEnum.PRIN, new Money().addTo(var.getAfPrinBal()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY, new Money().addTo(var.getAfPrinPenalBal()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.INTR, new Money().addTo(var.getAfIntrBal()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY, new Money().addTo(var.getAfIntrPenalBal()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.FEE, new Money().addTo(var.getAfFeeBal()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.FEE_PNY, new Money().addTo(var.getAfFeePenalBal()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.OTHER_FEE,new Money().addTo(var.getAfOtherFeeBal()));
        return debtMoney;
    }
    
    private static DebtMoney createAmt(LoanInstalLogDO var) {
        DebtMoney debtMoney = new DebtMoney();
        debtMoney.setByFieldType(DebtMoneyFieldEnum.PRIN, new Money().addTo(var.getPrinAmt()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY, new Money().addTo(var.getPrinPenalAmt()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.INTR, new Money().addTo(var.getIntrAmt()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY, new Money().addTo(var.getIntrPenalAmt()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.FEE, new Money().addTo(var.getFeeAmt()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.FEE_PNY, new Money().addTo(var.getFeePenalAmt()));
        debtMoney.setByFieldType(DebtMoneyFieldEnum.OTHER_FEE,new Money().addTo(var.getOtherFeeAmt()));
        return debtMoney;
    }
    
    private static DebtMoney createPaidFundAmt(LoanInstalLogDO var) {
        DebtMoney debtMoney = new DebtMoney();
        debtMoney.setByFieldType(DebtMoneyFieldEnum.PRIN, var.getPaidPrinFundAmt());
        debtMoney.setByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY, var.getPaidPrinPenalFundAmt());
        debtMoney.setByFieldType(DebtMoneyFieldEnum.INTR, var.getPaidIntrFundAmt());
        debtMoney.setByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY, var.getPaidIntrPenalFundAmt());
        debtMoney.setByFieldType(DebtMoneyFieldEnum.FEE, var.getPaidFeeFundAmt());
        debtMoney.setByFieldType(DebtMoneyFieldEnum.FEE_PNY, var.getPaidFeePenalFundAmt());
        debtMoney.setByFieldType(DebtMoneyFieldEnum.OTHER_FEE,var.getPaidOtherFeeFundAmt());
        return debtMoney;
    }
}
