/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.model.convertor;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.PlanCapitalOrderDO;
import com.abssqr.plat.common.facade.enums.AccountTypeEnum;
import com.abssqr.plat.common.facade.enums.PlanCapitalTransTypeEnum;
import com.abssqr.plat.common.facade.enums.TaskStatusEnum;
import com.abssqr.plat.common.facade.model.account.Account;
import com.abssqr.plat.common.facade.model.plan.PlanCapitalOrder;
import com.abssqr.plat.common.model.utils.TextUtil;
import com.general.system.tool.util.ToolUtil;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;

import java.util.List;

/**
 *
 * @author zhenxuan.luo
 * @version com.abssqr.plat.common.model.convertor: PlanCapitalOrderConvertor.java, v 0.1 2019-05-28 15:11 zhenxuan.luo Exp $
 */
public class PlanCapitalOrderConvertor {
    
    public static List<PlanCapitalOrder> convert2Domains(List<PlanCapitalOrderDO> var){
        List<PlanCapitalOrder> res = Lists.newArrayList();
        if (ToolUtil.isNotEmpty(var)) {
            for (PlanCapitalOrderDO ordrDO : var) {
                res.add(PlanCapitalOrderConvertor.convert2Domain(ordrDO));
            }
        }
        return res;
    }
    public static PlanCapitalOrder convert2Domain(PlanCapitalOrderDO var) {
        
        if (var == null) {
            return null;
        }
        
        PlanCapitalOrder res = new PlanCapitalOrder();
        
        res.setPlanNo(var.getPlanNo());
        res.setBizNo(var.getBizNo());
        res.setSeqNo(var.getSeqNo());
        res.setTransAmt(var.getTransAmt());
        res.setPayableAmt(var.getPayableAmt());
        res.setAccountDate(var.getAccountDate());
        res.setTransTime(var.getTransTime());
        res.setTransType(PlanCapitalTransTypeEnum.getByCode(var.getTransType()));
        res.setCapitalType(var.getCapitalType());
        if (StringUtils.isNotBlank(var.getPlanAcct())) {
            Account account = new Account();
            account.setActType(AccountTypeEnum.getByCode(var.getPlanAcctType()));
            account.setActNo(var.getPlanAcct());
            account.setActName(var.getPlanAcctName());
            account.setActProv(var.getPlanAcctProv());
            account.setActCity(var.getPlanAcctCity());
            account.setActBank(var.getPlanAcctBank());
            account.setChannelNo(var.getPlanAcctChannel());
            res.setPlanAcct(account);
        }
        
        res.setCntPtyCode(var.getCntPtyCode());
        if (StringUtils.isNotBlank(var.getCntPtyAcct())) {
            Account account = new Account();
            account.setActType(AccountTypeEnum.getByCode(var.getCntPtyAcctType()));
            account.setActNo(var.getCntPtyAcct());
            account.setActName(var.getCntPtyAcctName());
            account.setActProv(var.getCntPtyAcctProv());
            account.setActCity(var.getCntPtyAcctCity());
            account.setActBank(var.getCntPtyAcctBank());
            account.setChannelNo(var.getCntPtyAcctChannel());
            res.setCntPtyAcct(account);
        }
        
        res.setMemo(var.getMemo());
        res.setContext(TextUtil.convertTxt2Map(var.getContext()));
        res.setStatus(TaskStatusEnum.getByCode(var.getStatus()));
        res.setOutAcptNo(var.getOutAcptNo());
        res.setOutTransNo(var.getOutTransNo());
        res.setFinishTime(var.getFinishTime());
        res.setCfrmAmt(var.getCfrmAmt());
        res.setProcTime(var.getProcTime());
        res.setExecTimes(var.getExecTimes());
        res.setLastExecTime(var.getLastExecTime());
        res.setNextExecTime(var.getNextExecTime());
        return res;
    }
    
    public static PlanCapitalOrderDO convert2DO(PlanCapitalOrder var) {
        
        if (var == null) {
            return null;
        }
    
        PlanCapitalOrderDO res = new PlanCapitalOrderDO();
        
        res.setPlanNo(var.getPlanNo());
        res.setBizNo(var.getBizNo());
        res.setSeqNo(var.getSeqNo());
        res.setTransAmt(var.getTransAmt());
        res.setPayableAmt(var.getPayableAmt());
        res.setAccountDate(var.getAccountDate());
        res.setTransTime(var.getTransTime());
        res.setTransType(var.getTransType().getCode());
        res.setCapitalType(var.getCapitalType());
        if (var.getPlanAcct() != null) {
            res.setPlanAcct(var.getPlanAcct().getActNo());
            res.setPlanAcctName(var.getPlanAcct().getActName());
            res.setPlanAcctBank(var.getPlanAcct().getActBank());
            res.setPlanAcctProv(var.getPlanAcct().getActProv());
            res.setPlanAcctCity(var.getPlanAcct().getActCity());
            res.setPlanAcctType(var.getPlanAcct().getActType().getCode());
            res.setPlanAcctChannel(var.getPlanAcct().getChannelNo());
        }
        
        res.setCntPtyCode(var.getCntPtyCode());
        if (var.getCntPtyAcct() != null) {
            res.setCntPtyAcct(var.getCntPtyAcct().getActNo());
            res.setCntPtyAcctName(var.getCntPtyAcct().getActName());
            res.setCntPtyAcctBank(var.getCntPtyAcct().getActBank());
            res.setCntPtyAcctProv(var.getCntPtyAcct().getActProv());
            res.setCntPtyAcctCity(var.getCntPtyAcct().getActCity());
            res.setCntPtyAcctType(var.getCntPtyAcct().getActType().getCode());
            res.setCntPtyAcctChannel(var.getCntPtyAcct().getChannelNo());
        }
        
        res.setMemo(var.getMemo());
        res.setContext(TextUtil.convertMap2Txt(var.getContext()));
        res.setStatus(var.getStatus().getCode());
        res.setOutAcptNo(var.getOutAcptNo());
        res.setOutTransNo(var.getOutTransNo());
        res.setFinishTime(var.getFinishTime());
        res.setCfrmAmt(var.getCfrmAmt());
        res.setProcTime(var.getProcTime());
        res.setExecTimes(var.getExecTimes());
        res.setLastExecTime(var.getLastExecTime());
        res.setNextExecTime(var.getNextExecTime());
        return res;
    }
}