/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.model.domain.ast;

import com.abssqr.plat.common.facade.enums.DebtMoneyFieldEnum;
import com.abssqr.plat.common.util.utils.BigDecimalUtil;
import com.general.system.common.model.BaseEntity;
import com.general.system.common.model.Money;
import com.general.system.common.util.VarChecker;

import java.math.BigDecimal;

/**
 *
 * @author zhenxuan.luo
 * @version com.abssqr.plat.core.service.profit.entity: AstProfitSplitRes.java, v 0.1 2019-11-17 下午16:38 zhenxuan.luo Exp $ 
 */
public class AstProfitUnit<T> extends BaseEntity {
    
    private DebtMoneyFieldEnum field;
    
    private Money base = new Money();
    
    private Money entryAmt = new Money();
    
    private BigDecimal entryDec = BigDecimal.ZERO;
    
    private Money transEntryAmt = new Money();
    
    private BigDecimal transEntryDec = BigDecimal.ZERO;
    
    /**
     *
     * @param base
     * @param entryAmt
     * @param entryDec
     */
    public AstProfitUnit(DebtMoneyFieldEnum field, Money base, Money entryAmt, BigDecimal entryDec) {
        this.field = field;
        this.base = base.clone();
        this.entryAmt = entryAmt.clone();
        this.entryDec = BigDecimalUtil.clone(entryDec);
    }
    
    public AstProfitUnit(DebtMoneyFieldEnum field) {
        this.field = field;
    }
    
    public void append(AstProfitUnit astProfitUnit) {
        this.base.addTo(astProfitUnit.base);
        this.entryAmt.addTo(astProfitUnit.entryAmt);
        this.entryDec = this.entryDec.add(astProfitUnit.entryDec);
    }
    
    public void trans(Money entryAmt, BigDecimal entryDec) {
        VarChecker.checkArgument(!entryAmt.isNegtive(), "收益分配入账金额[{0}]不能为负", entryAmt);
        VarChecker.checkArgument(!BigDecimalUtil.isNegative(entryDec), "收益分配入账实数[{0}]不能为负", entryDec);
        
        this.transEntryDec = this.transEntryDec.add(entryDec);
        this.transEntryAmt.addTo(entryAmt);
        
        this.entryAmt.addTo(entryAmt);
        this.entryDec = this.entryDec.add(entryDec);
    }
    
    public Money getBase() {
        return base;
    }
    
    public Money getEntryAmt() {
        return entryAmt;
    }
    
    public BigDecimal getEntryDec() {
        return entryDec;
    }
    
    public void setBase(Money base) {
        this.base = base;
    }
    
    public void setEntryAmt(Money entryAmt) {
        this.entryAmt = entryAmt;
    }
    
    public void setEntryDec(BigDecimal entryDec) {
        this.entryDec = entryDec;
    }
    
    public Money getTransEntryAmt() {
        return transEntryAmt;
    }
    
    public void setTransEntryAmt(Money transEntryAmt) {
        this.transEntryAmt = transEntryAmt;
    }
    
    public BigDecimal getTransEntryDec() {
        return transEntryDec;
    }
    
    public void setTransEntryDec(BigDecimal transEntryDec) {
        this.transEntryDec = transEntryDec;
    }
    
    public DebtMoneyFieldEnum getField() {
        return field;
    }
    
}