/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.model.domain.ast;

import com.abssqr.plat.common.facade.base.DebtMoney;
import com.abssqr.plat.common.facade.enums.EventCodeEnum;
import com.abssqr.plat.common.facade.enums.TransCodeEnum;
import com.abssqr.plat.common.model.domain.loanTrans.LoanAstProfitTransDetail;
import com.abssqr.plat.common.model.domain.loanTrans.LoanInstalTransDetail;
import com.abssqr.plat.common.model.utils.LoanAstUtil;
import com.general.system.common.model.BaseEntity;
import com.general.system.common.util.VarChecker;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 *
 * @author zhenxuan.luo
 * @version com.abssqr.plat.common.model.domain.ast: LoanAstProfitGroup.java, v 0.1 2019-11-13 下午16:21 zhenxuan.luo Exp $ 
 */
public class LoanAstProfitGroup extends BaseEntity {
    
    private LoanAstProfit ownAstProfit;
    
    private LoanAstProfit splitAstProfit;
    
    public void checkSelf(LoanAst loanAst) {
        
        VarChecker.checkNotNull(ownAstProfit, "机构资产[{0}]持有收益不存在", loanAst.getLoanAstNo());
        
        ownAstProfit.checkSelf();
        if (splitAstProfit != splitAstProfit) {
            splitAstProfit.checkSelf();
        }
    }
    
    public List<LoanAstProfitTransDetail> settle(LoanAstMeasure astMeasure, LoanInstalTransDetail instalTransDetail, String memo) {
        
        List<LoanAstProfitTransDetail> ret = Lists.newArrayList();
        EventCodeEnum eventCode = instalTransDetail.getActiveLog().getEventCode();

        VarChecker.checkArgument(eventCode.getSceneCode() == TransCodeEnum.INTR_FEE_SETTLEMENT ||
                                 eventCode.getSceneCode() == TransCodeEnum.AST_SIMU||
                                eventCode.getSceneCode() == TransCodeEnum.HANG_FEE,
                "[{0}-{1}-{2}]事件码[{3}]不是结息交易，不能做结息处理",
                astMeasure.getLoanAst().getLoanAstNo(), astMeasure.getSrcTerm(), ownAstProfit.getAstProfitNo(),
                eventCode);

        LoanAstProfitTransDetail ownTransDetail = LoanAstProfitTransDetail
                                                          .createTransDtl(ownAstProfit, instalTransDetail, eventCode, false);
        ownTransDetail.getActiveLog().setMemo(memo);
        
        ret.add(ownTransDetail);

        // 入账金额维护
        ownTransDetail.entryDec(astMeasure);
        
        // 结息发生额
        DebtMoney settleAmt = astMeasure.filterTransEntryAmt();
        
        // 需要分润
        if (StringUtils.isNotBlank(ownAstProfit.getSplitOrgCode())) {
            
            BigDecimal splitRate = ownAstProfit.getSplitRate();
            LoanAstProfitMeasure splitProfitMeasure = buildSplitMeasure(astMeasure, instalTransDetail);
            LoanAstProfitMeasure ownProfitMeasure = LoanAstProfitMeasure.buildByLoanAstProfit(ownAstProfit);
            
            splitProfitMeasure.calcSpit(splitRate, astMeasure, ownProfitMeasure);
            
            LoanAstProfitTransDetail splitTransDetail = LoanAstProfitTransDetail
                                                                .createTransDtl(splitAstProfit, instalTransDetail,
                                                                        eventCode);
            ret.add(splitTransDetail);
            
            // 入账金额维护
            splitTransDetail.entryDec(splitProfitMeasure);
            
            // 结息发生额
            DebtMoney splitTransAmt = splitProfitMeasure.filterTransEntryAmt();
            splitTransDetail.processTransAmt(splitTransAmt);
            settleAmt.subAll(splitTransAmt);
        }
        
        ownTransDetail.processTransAmt(settleAmt);
        
        return ret;
    }
    
    private LoanAstProfitMeasure buildSplitMeasure(LoanAstMeasure astMeasure, LoanInstalTransDetail instalTransDetail) {
        LoanAst loanAst = astMeasure.getLoanAst();
        Date accountDate = instalTransDetail.getActiveLog().getAccountDate();
        
        if (null == splitAstProfit) {
            splitAstProfit = LoanAstUtil.buildSplitProfit(instalTransDetail.getLoanInstal(), ownAstProfit, accountDate);
        }
        
        LoanAstProfitMeasure splitAstMeasure = LoanAstProfitMeasure.buildByLoanAstProfit(splitAstProfit);
        
        return splitAstMeasure;
    }
    
    public LoanAstProfit getOwnAstProfit() {
        return ownAstProfit;
    }
    
    public void setOwnAstProfit(LoanAstProfit ownAstProfit) {
        this.ownAstProfit = ownAstProfit;
    }
    
    public LoanAstProfit getSplitAstProfit() {
        return splitAstProfit;
    }
    
    public void setSplitAstProfit(LoanAstProfit splitAstProfit) {
        this.splitAstProfit = splitAstProfit;
    }
    
}