/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.model.domain.loanTrans;

import com.abssqr.plat.common.facade.base.DebtMoney;
import com.abssqr.plat.common.facade.enums.DebtMoneyFieldEnum;
import com.abssqr.plat.common.facade.enums.EventCodeEnum;
import com.abssqr.plat.common.facade.enums.ProfitTypeEnum;
import com.abssqr.plat.common.facade.enums.TransCodeEnum;
import com.abssqr.plat.common.model.domain.ast.Loan;
import com.abssqr.plat.common.model.domain.ast.LoanAstProfit;
import com.abssqr.plat.common.model.domain.ast.ProfitMeasure;
import com.abssqr.plat.common.model.domain.rule.LoanAstBalAndPrice;
import com.abssqr.plat.common.model.domain.rule.LoanAstProfitBalAndPrice;
import com.abssqr.plat.common.model.seq.SequenceUtil;
import com.abssqr.plat.common.util.utils.BigDecimalUtil;
import com.general.system.common.model.Money;
import com.general.system.common.util.DateTimeUtil;

import java.math.BigDecimal;

/**
 *
 * @author zhenxuan.luo
 * @version com.abssqr.plat.common.model.domain.loanTrans: LoanAstProfitTransDetail.java, v 0.1 2019-11-13 下午14:10 zhenxuan.luo Exp $ 
 */
public class LoanAstProfitTransDetail implements ITransDtl {
    
    /**
     * 机构资产收益
     */
    private LoanAstProfit    loanAstProfit;
    /**
     * 机构资产收益流水
     */
    private LoanAstProfitLog activeLog;
    /**
     * 是否更新
     */
    private boolean          isUpdate = false;
    
    private LoanAstProfitTransDetail() {
    }
    
    public static LoanAstProfitTransDetail createTransDtl(LoanAstProfit loanAstProfit,
                                                          LoanInstalTransDetail loanInstalTransDetail,
                                                          EventCodeEnum eventCode) {
        return createTransDtl(loanAstProfit, loanInstalTransDetail, eventCode, true);
    }
    
    /**
     * 构建
     *
     * @param loanAstProfit
     * @param loanInstalTransDetail
     * @return
     */
    public static LoanAstProfitTransDetail createTransDtl(LoanAstProfit loanAstProfit,
                                                          LoanInstalTransDetail loanInstalTransDetail,
                                                          EventCodeEnum eventCode, boolean checkNew) {
        
        // 1. 构造资产交易明细
        LoanAstProfitTransDetail transDetail = new LoanAstProfitTransDetail();
        
        // 2. 构造交易流水
        LoanAstProfitLog log = buildLog(loanAstProfit, loanInstalTransDetail, eventCode);
        
        transDetail.loanAstProfit = loanAstProfit;
        transDetail.activeLog = log;
        
        if (checkNew && loanAstProfit.isNew() && loanAstProfit.getTermNo() == loanAstProfit.getSrcTermNo()
            && loanAstProfit.getProfitType() == ProfitTypeEnum.OWN) {
            transDetail.isUpdate = true;
        }
        
        loanInstalTransDetail.getLoanAstProfitTransDetails().add(transDetail);
        
        return transDetail;
    }
    
    private static LoanAstProfitLog buildLog(LoanAstProfit loanAstProfit, LoanInstalTransDetail loanInstalTransDetail,
                                             EventCodeEnum eventCode) {
        
        LoanInstalLog loanInstalLog = loanInstalTransDetail.getActiveLog();
        LoanAstProfitLog log = new LoanAstProfitLog();
        Loan loan = loanInstalTransDetail.getLoanTransDetail().getLoan();
        
        log.setAstNo(loanAstProfit.getAstNo());
        log.setOutAstNo(loanAstProfit.getOutAstNo());
        log.setOwnOrg(loanAstProfit.getOwnOrg());
        log.setLoanAstNo(loanAstProfit.getLoanAstNo());
        log.setProfitType(loanAstProfit.getProfitType());
        log.setAstProfitNo(loanAstProfit.getAstProfitNo());
        log.setSplitOrgCode(loanAstProfit.getSplitOrgCode());
        log.setTermNo(loanAstProfit.getTermNo());
        log.setSrcTermNo(loanAstProfit.getSrcTermNo());
        log.setBizTermNo(loanInstalLog.getTermNo());
        
        log.setSeqNo(SequenceUtil.genSeqByLoan(loan, eventCode.getSceneCode()));
        // 用分期的流水号，便于区分不同分期发起的交易
        log.setBizNo(loanInstalLog.getSeqNo());
        log.setOutBizNo(loanInstalLog.getOutBizNo());
        log.setExecTms(loanInstalLog.getExecTms());
        log.setTransTime(loanInstalLog.getTransTime());
        log.setAccountDate(loanInstalLog.getAccountDate());
        log.setEventCode(eventCode);
        
        if (loanAstProfit.getProfitType() == ProfitTypeEnum.SPLIT) {
            log.setSplitOrgCode(loanAstProfit.getRefLoanAst().getOwnOrg());
        }
        return log;
    }
    
    public void entryDec(ProfitMeasure astMeasure) {
        if (astMeasure.filterTransEntryAmt().getSum().isZero() && BigDecimalUtil.isZero(astMeasure.getTransDecSum())) {
            return;
        }
        this.isUpdate = true;
        
        this.loanAstProfit.setIntrEntryDec(astMeasure.getIntrEntry().getEntryDec());
        this.loanAstProfit.setIntrPenalEntryDec(astMeasure.getIntrPenalEntry().getEntryDec());
        this.loanAstProfit.setPrinPenalEntryDec(astMeasure.getPrinPenalEntry().getEntryDec());
        this.loanAstProfit.setFeeEntryDec(astMeasure.getFeeEntry().getEntryDec());
        this.loanAstProfit.setFeePenalEntryDec(astMeasure.getFeePenalEntry().getEntryDec());
        this.loanAstProfit.setOtherFeeEntryDec(astMeasure.getOtherFeeEntry().getEntryDec());
        this.loanAstProfit.setEntryAmt(astMeasure.filterEntryAmt());
    }
    
    public void processTransFundAmt(Money transAmt, DebtMoneyFieldEnum fieldEnum) {
        DebtMoney amt = new DebtMoney();
        amt.setByFieldType(fieldEnum, transAmt);
        processTransFundAmt(amt);
    }
    
    public void processTransFundAmt(DebtMoney transAmt) {
        if (transAmt.isZero()) {
            return;
        }
        isUpdate = true;
        
        this.activeLog.getFundAmt().addAll(transAmt, DebtMoneyFieldEnum.PRIN);
        this.loanAstProfit.getFundAmt().addAll(transAmt, DebtMoneyFieldEnum.PRIN);
    }

    public void processTransAmt(Money transAmt, DebtMoneyFieldEnum fieldEnum) {
        DebtMoney amt = new DebtMoney();
        amt.setByFieldType(fieldEnum, transAmt);
        processTransAmt(amt);
    }
    
    public void processTransAmt(DebtMoney transAmt) {
        if (transAmt.getSum().isZero()) {
            return;
        }
        isUpdate = true;
        DebtMoney curBal = this.loanAstProfit.getBal();
        DebtMoney newBal = new DebtMoney();
        transAmt = transAmt.cloneAll(DebtMoneyFieldEnum.PRIN);
        this.activeLog.getAmt().addAll(transAmt, DebtMoneyFieldEnum.PRIN);
        // 1. 根据事件码，设定符号
        int sign = this.activeLog.getEventCode().getAssetFlow().getSign();
        
        // 2. 计算交易后余额
        for (DebtMoneyFieldEnum debtMoneyField : DebtMoneyFieldEnum.values()) {
            Money curBalField = curBal.getByFieldType(debtMoneyField);
            Money transAmtField = transAmt.getByFieldType(debtMoneyField);
            Money newBalField = curBalField.add(transAmtField.multiply(sign));
            newBal.setByFieldType(debtMoneyField, newBalField);
        }
        
        if (this.activeLog.getEventCode().getSceneCode() == TransCodeEnum.REPO) {
            this.loanAstProfit.getPaidAmt().addAll(transAmt);
        } else if (this.activeLog.getEventCode().getSceneCode() == TransCodeEnum.EXMPT) {
            this.loanAstProfit.getRmtAmt().addAll(transAmt);
        }
        
        // 3. 回填余额
        this.loanAstProfit.setBal(newBal);
    }
    
    public void processTransAmtOnly(DebtMoney transAmt) {
        this.activeLog.getAmt().addAll(transAmt, DebtMoneyFieldEnum.PRIN);
    }
    
    public LoanAstProfit getLoanAstProfit() {
        return loanAstProfit;
    }
    
    public LoanAstProfitLog getActiveLog() {
        return activeLog;
    }
    
    public boolean isUpdate() {
        return isUpdate;
    }
    
    public void setUpdate(boolean isUpdate) {
        this.isUpdate = isUpdate;
    }
    
    @Override
    public void processBeforeUpdate() {
        activeLog.setAfBal(loanAstProfit.getBal().cloneAll());
        if (isUpdate) {
            // 3. 处理初笔交易
            if (DateTimeUtil.isBeforeOnDate(loanAstProfit.getLastUpdateDate(), this.getActiveLog().getAccountDate())) {
                loanAstProfit.setLastUpdateDate(this.getActiveLog().getAccountDate());
            }
        }
    }
    
    /**
     * 回购处理收益转入
     * @param srcProfit         原机构收益
     * @param profitBalAndPrice    收益定价模型
     */
    public void transIn(LoanAstProfit srcProfit, LoanAstProfitBalAndPrice profitBalAndPrice) {
        this.setUpdate(true);
        // 定价
        DebtMoney priceAmt = profitBalAndPrice.turnPrice();
        // 余额
        DebtMoney bal = srcProfit.getBal();
        // 记录发生额
        activeLog.getAmt().addAll(bal, DebtMoneyFieldEnum.PRIN, DebtMoneyFieldEnum.OVD_PRIN);
        // 清算金额
        activeLog.setClrgAmt(priceAmt.getAllIntAndFee());
        
        // 回填余额
        this.loanAstProfit.getBal().addAll(bal, DebtMoneyFieldEnum.PRIN, DebtMoneyFieldEnum.OVD_PRIN);
        
        // 记录成本
        this.loanAstProfit.setCostAmt(priceAmt.getAllIntAndFee());
    
        // 记录扩展呢信息
        LoanAstBalAndPrice balAndPrice = new LoanAstBalAndPrice();
        balAndPrice.setBal(bal.cloneAll());
        balAndPrice.setPrice(priceAmt.cloneAll());
        // 记录扩展信息
        this.loanAstProfit.setExtInfo(profitBalAndPrice.getExtText());
        
        // 入账实数复制
        this.loanAstProfit.setIntrEntryDec(srcProfit.getIntrEntryDec());
        this.loanAstProfit.setIntrPenalEntryDec(srcProfit.getIntrPenalEntryDec());
        this.loanAstProfit.setPrinPenalEntryDec(srcProfit.getPrinPenalEntryDec());
        this.loanAstProfit.setFeeEntryDec(srcProfit.getFeeEntryDec());
        this.loanAstProfit.setFeePenalEntryDec(srcProfit.getFeePenalEntryDec());
        // 对应入账实数金额复制
        this.loanAstProfit.getEntryAmt().addAll(srcProfit.getEntryAmt(), DebtMoneyFieldEnum.PRIN, DebtMoneyFieldEnum.OVD_PRIN);
    }

    /**
     * 回购处理收益转出
     * @param profitBalAndPrice 收益定价模型
     */
    public void transOut(LoanAstProfitBalAndPrice profitBalAndPrice) {
        this.setUpdate(true);
        // 定价
        DebtMoney priceAmt = profitBalAndPrice.turnPrice();
        // 余额
        DebtMoney bal = this.getLoanAstProfit().getBal();
        // 记录发生额
        this.activeLog.getAmt().addAll(bal, DebtMoneyFieldEnum.PRIN, DebtMoneyFieldEnum.OVD_PRIN);
        this.activeLog.setClrgAmt(priceAmt.getAllIntAndFee());
        
        DebtMoney subBal = bal.cloneAll(DebtMoneyFieldEnum.PRIN, DebtMoneyFieldEnum.OVD_PRIN);
        // 回填余额
        this.loanAstProfit.getBal().subAll(subBal);
        
        // 记录扩展信息
        this.loanAstProfit.setExtInfo(profitBalAndPrice.getExtText());
    
        // 入账实数请空
        this.loanAstProfit.setIntrEntryDec(BigDecimal.ZERO);
        this.loanAstProfit.setIntrPenalEntryDec(BigDecimal.ZERO);
        this.loanAstProfit.setPrinPenalEntryDec(BigDecimal.ZERO);
        this.loanAstProfit.setFeeEntryDec(BigDecimal.ZERO);
        this.loanAstProfit.setFeePenalEntryDec(BigDecimal.ZERO);
        
        // 对应入账实数金额请空
        this.loanAstProfit.setEntryAmt(new DebtMoney());
    }

}