/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2020 All Rights Reserved. 
 */
package com.abssqr.plat.common.model.enums;

import com.general.system.common.model.IEnum;

import java.util.HashMap;
import java.util.Map;

/**
 * 会计日机构编码枚举
 * @author hanfei
 * @version $Id: OrgCodeEnum.java, v 0.1 2020-03-03 4:43 PM hanfei Exp $
 */
public enum OrgCodeEnum implements IEnum<String> {
    
    ABS("ABS", "转让系统", OrgTypeEnum.ABS, ""),
    WK1009("1009", "招联资产机构", OrgTypeEnum.AST, "3"),
    WK1011("1011", "美团资产机构", OrgTypeEnum.AST, "4"),
    
    ;
    
    private static final Map<String, OrgCodeEnum> codeMap = new HashMap<String, OrgCodeEnum>();
    static {
        for (OrgCodeEnum item : OrgCodeEnum.values()) {
            codeMap.put(item.getCode(), item);
        }
    }
    
    /**
     * 机构编码
     */
    private String      code;
    private String      desc;
    /**
     * 对应机构编码的类型
     */
    private OrgTypeEnum type;
    /**
     * 五矿数据控制标记类型
     */
    private String      ctrFlg;
    
    OrgCodeEnum(String code, String desc, OrgTypeEnum type, String ctrFlg) {
        this.code = code;
        this.desc = desc;
        this.type = type;
        this.ctrFlg = ctrFlg;
    }
    
    public static OrgCodeEnum getByCode(String code) {
        return codeMap.get(code);
    }
    
    @Override
    public String getCode() {
        return code;
    }
    
    @Override
    public String getDesc() {
        return desc;
    }
    
    public OrgTypeEnum getType() {
        return type;
    }
    
    public String getCtrFlg() {
        return ctrFlg;
    }
}
