/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2020 All Rights Reserved.
 */

package com.abssqr.plat.common.model.repo.ast.impl;

import java.util.Date;
import java.util.List;

import com.abssqr.plat.common.dal.mysql.auto.dao.AstPackDAO;
import com.abssqr.plat.common.dal.mysql.auto.dao.LoanPackRelDAO;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.AstPackDO;
import com.abssqr.plat.common.dal.mysql.auto.paging.AstPackPagePage;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.LoanPackRelSummary;
import com.abssqr.plat.common.facade.enums.AstPackStatusEnum;
import com.abssqr.plat.common.facade.param.ast.AstPackQryParam;
import com.abssqr.plat.common.model.convertor.AstPackConvert;
import com.abssqr.plat.common.model.domain.ast.AstPack;
import com.abssqr.plat.common.model.repo.ast.AstPackRepo;

import com.general.system.common.util.VarChecker;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @author xiachenxiang
 * @version com.abssqr.plat.common.model.repo.ast.impl: AstPackRepositoryImpl.java, v 0.1 2020-04-18 3:16 PM xiachenxiang Exp $
 */
@Component
public class AstPackRepoImpl implements AstPackRepo {
    @Autowired
    private AstPackDAO astPackDAO;

    @Override
    public AstPack getByAbsPackPackNo(String packNo) {
        return AstPackConvert.convertDomain(astPackDAO.getByAbsPackPackNo(packNo));
    }

    @Override
    public Long cntByPackName(String packName) {
        return astPackDAO.cntByPackName(packName);
    }

    @Override
    public int insert(AstPack pack){
        return astPackDAO.insert(AstPackConvert.convertDO(pack));
    }

    @Override
    public AstPackPagePage getList(AstPackQryParam param) {
        AstPackPagePage page = new AstPackPagePage();
        page.setPackNo(param.getPackNo());
        page.setPackName(param.getPackName());
        List<String > status = Lists.newArrayList();
        if (StringUtils.isNotEmpty(param.getStatus())){
            status.add(param.getStatus());
            // init 在前端也显示为筛选中
            if (StringUtils.equals(param.getStatus(),AstPackStatusEnum.EXEC.getCode())){
                status.add(AstPackStatusEnum.INIT.getCode());
            }
        }
        page.setStatus(status);
        page.setLimit(param.getPageSize());
        page.setCurrPageNo(param.getPageNum());
        return astPackDAO.getList(page);
    }


    /**
     * 封包
     *
     * @param packNo         包编号
     * @param packSubmitDate 封包提交日
     * @param sealPackDate   封包日
     */
    @Override
    public void sealPack(String packNo, Date packSubmitDate, Date sealPackDate) {
        int i = astPackDAO.updateSealPack(sealPackDate, packSubmitDate, packNo);
        VarChecker.checkEquals(i,1,"封包失败");
    }

    /**
     * 解包
     *
     * @param packNo
     */
    @Override
    public void unPack(String packNo) {
        int i = astPackDAO.updateUnPack(packNo);
        VarChecker.checkEquals(i,1,"解包失败");
    }

    /**
     * 解包
     *
     * @param packNo
     */
    @Override
    public void splitPack(String packNo) {
        int i = astPackDAO.updateSplitPack(packNo);
        VarChecker.checkEquals(i,1,"拆包失败");
    }

    /**
     * 锁
     *
     * @param packNo
     * @return
     */
    @Override
    public AstPack lockAstPack(String packNo) {
        AstPackDO astPackDO = astPackDAO.getForLock(packNo);
        return AstPackConvert.convertDomain(astPackDO);
    }

    /**
     * @param packNo
     */
    @Override
    public void screenFisPack(String packNo) {
        int i =  astPackDAO.updateScreenFis(packNo);
        VarChecker.checkEquals(i,1,"更新包状态失败");
    }
}
