/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2019 All Rights Reserved.
 */
package com.abssqr.plat.common.model.repo.plan;

import com.abssqr.plat.common.facade.enums.PlanAllocStatusEnum;
import com.abssqr.plat.common.facade.enums.PlanTypeEnum;
import com.abssqr.plat.common.facade.model.plan.PlanAlloc;
import com.abssqr.plat.common.facade.model.plan.PlanAllocItem;
import com.general.system.common.model.Money;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 分配计划
 * @author bangis.wangdf
 * @version com.abssqr.plat.common.model.repo.plan: PlanAllocRepo.java, v 0.1 2019-06-03 16:53 bangis.wangdf Exp $ 
 */
public interface PlanAllocRepo {
    /**
     * 获取分配计划
     * @param planNo
     * @return
     */
    List<PlanAlloc> queryByPlanNo(String planNo);
    
    /**
     * 获取未分配审批通过的分配计划
     * @param planNo
     * @return
     */
    List<PlanAlloc> queryUnassigneAllocByPlanNo(String planNo);
    
    void insertPlanAllocs(List<PlanAlloc> allocs);

    PlanAlloc getPlanAllocDetail(String allocNo);
    
    void addOrUpdate(PlanAlloc param, boolean upd);

    /**
     * 删除分配方案
     * @param allocNo
     * @return
     */
    int delete(String allocNo);
    /**
     * 删除分配事项
     *
     * @param itemNo
     * @return
     */
    int deleteAllocItem(String itemNo);
    /**
     * 分配计划改为已分配
     * @param allocNo
     * @param allocStatus
     * @return
     */
    Boolean planAllocDetailAssigned(String allocNo, PlanAllocStatusEnum allocStatus);
    
    /**
     * 获取最近一次兑付
     * @return
     */
    PlanAlloc queryRecentlyPlans(PlanTypeEnum planType);
    
    int updateAllocStatus(PlanAlloc alloc);
    
    int querySameClearDate(Date clearDate,String planNo,String allocNo);
    
    PlanAlloc lockByAllocNo(String allocNo);
    
    /**
     * 查询审批通过并且未分配的时间段分配金额统计
     * @return
     */
    Money queryStatAllocAmtByPlanNoAndPayDate(Date startDate, Date endDate,String planNo);
    
    /**
     * 根据计划编号获取累计分配金额
     * @param planNos
     * @return
     */
    Money queryStatTotalAllocAmtByPlanNos(List<String> planNos);

    void insertPlanAllocItem(PlanAllocItem allocItem, String planNo, String allocNo);

    /**
     * 根据计划编号删除分配方案
     * @param planNo planNo
     */
    void cleanByPlanNo(String planNo);

    List<PlanAlloc> queryUnMatchedApprovedAlloc(String planNo);

    /**
     * 查询已分配未兑付的金额 按投资结构分组
     * @param planNo 计划编号
     * @return
     */
    Map<String,Money> queryApprovedNotPayMoneyGroupByLayerNo(String planNo);
}
