/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2018 All Rights Reserved.
 */
package com.abssqr.plat.common.model.repo.plan.impl;

import com.abssqr.plat.common.dal.mysql.auto.dao.PlanAstDAO;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.PlanAstDO;
import com.abssqr.plat.common.facade.enums.PlanTypeEnum;
import com.abssqr.plat.common.model.convertor.PlanAstConvert;
import com.abssqr.plat.common.facade.model.plan.PlanAst;
import com.abssqr.plat.common.model.repo.plan.PlanAstRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * @author hanfei
 * @version $Id: PlanAstRepositoryImpl.java, v 0.1 2018-01-04 下午8:01 hanfei Exp $
 */
@Repository
public class PlanAstRepositoryImpl implements PlanAstRepository {

    //log
    private static final Logger logger = LoggerFactory.getLogger(PlanAstRepositoryImpl.class);

    @Autowired
    private PlanAstDAO planAstDAO;

    /**
     * desc:插入计划资产水位表.<br/>
     *
     * @param planAst planAst
     * @return int
     */
    @Override
    public int create(PlanAst planAst) {
        PlanAstDO entity = PlanAstConvert.convertDO(planAst);
        return planAstDAO.insert(entity);
    }


    /**
     * 通过planNo查询
     *
     * @param planNo
     * @return
     */
    @Override
    public PlanAst getByPlanNo(String planNo) {
        PlanAst planAst = PlanAstConvert.convertDTO(planAstDAO.getByPlanNo(planNo));
        return planAst;
    }


    /**
     * desc:更新计划资产水位表.<br/>
     *
     * @param planAst planAst
     * @return int
     */
    @Override
    public int update(PlanAst planAst) {
        PlanAstDO entity = PlanAstConvert.convertDO(planAst);
        return planAstDAO.updateByPlanNo(entity);
    }

    /**
     * desc:根据 PLAN_NO 锁定日志记录数据.<br/>
     *
     * @param planNo planNo
     * @return PlanAstDO
     */
    @Override
    public PlanAst lockByPlanNo(String planNo) {
        return PlanAstConvert.convertDTO(planAstDAO.lockByPlanNoForUpdate(planNo));
    }
    
    @Override
    public Long getAllPlanAmt(PlanTypeEnum planType) {
        return planAstDAO.getAllAstAmt(planType.getCode());
    }

}
