/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2019 All Rights Reserved.
 */
package com.abssqr.plat.core.service.acct;

import com.abssqr.plat.common.facade.enums.AccountAttributeEnum;
import com.abssqr.plat.common.facade.enums.AccountTypeEnum;
import com.abssqr.plat.common.facade.model.account.Account;
import com.abssqr.plat.common.model.repo.acct.AcctRepo;
import com.general.system.tool.util.ToolUtil;
import com.google.common.collect.Lists;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 账户管理
 *
 * @author bangis.wangdf
 * @version com.abssqr.plat.core.service.acctday: AcctManager.java, v 0.1 2019-06-22 13:43 bangis.wangdf Exp $
 */
@Component
public class AcctManager {

    @Autowired
    private AcctRepo     acctRepo;

    /**
     * 新增or编辑银行账号
     *
     * @param planNo
     * @param accounts
     */
    public void addOrUpdateAccounts(String planNo, List<Account> accounts) {
        acctRepo.addOrUpdateAccounts(planNo, accounts);
    }

    /**
     * 获取账号列表 -- 账号类型list
     *
     * @param planNo
     * @param accountTypes
     * @return
     */
    public List<Account> getAllAcctByPlanNo(String planNo, List<AccountTypeEnum> accountTypes) {
        
        return acctRepo.getAcctByPlanNo(planNo, null, accountTypes);
    }

    /**
     * 获取账号列表 -- 指定账号类型--不包含余额查询
     *
     * @param planNo
     * @param actType
     * @return
     */
    public List<Account> getAcctByPlanNoAndType(String planNo, AccountTypeEnum actType) {
        return getAcctByPlanNoAndType(planNo, actType, false);
    }

    /**
     * 获取账号列表 -- 指定账号类型--包含余额查询
     *
     * @param planNo
     * @param actType
     * @return
     */
    public List<Account> getAcctByPlanNoAndType(String planNo, AccountTypeEnum actType, boolean balance) {
        //指定类型
        List<Account> accounts = acctRepo.selectByEntityCodeAndType(planNo, actType.getCode());
        //判断是否是银行账户
        boolean  isBank=AccountTypeEnum.BANK == actType;
        //如果是银行账户则完善银行账户信息，如果为虚拟户直接查询
        accounts = isBank ? this.selectPlatAccounts(accounts, planNo) : accounts;
        if (balance) {
            accounts.forEach(account -> {
                //如果是银行账户则查询映射渠道号，否则查询渠道号
                String actNo= isBank ? account.getMapActNo() : account.getActNo();
            });
        }
        return accounts;
    }
    

    
    /**
     * 查询虚拟户并添加虚拟号和对应渠道号至对应银行户
     *
     * @param bankAccounts
     * @param entityCode
     * @return
     */
    private List<Account> selectPlatAccounts(List<Account> bankAccounts, String entityCode) {
        //查询对应的虚拟户
        List<Account> platAccounts = acctRepo.getAcctByPlanNo(entityCode, null, Lists.newArrayList(
            AccountTypeEnum.PLAT_VIRTUAL));

        if (CollectionUtils.isNotEmpty(platAccounts)) {
            this.addWkActNo(bankAccounts, platAccounts);
        }
        return bankAccounts;
    }

    /**
     * 完善账户映射渠道号，编号基础方法
     *
     * @param bankAccounts
     * @param platAccounts
     * @return
     */
    private List<Account> addWkActNo(List<Account> bankAccounts, List<Account> platAccounts) {

        if (CollectionUtils.isNotEmpty(bankAccounts) && CollectionUtils.isNotEmpty(platAccounts)) {
            Map<AccountAttributeEnum, Account> platAccountMap =
                platAccounts.stream().collect(Collectors.toMap(Account::getActAttr, item -> item, (k1, k2) -> k1));

            bankAccounts.stream().forEach(account -> {
                Account platAccount = platAccountMap.get(account.getActAttr());
                if (ToolUtil.isNotEmpty(platAccount)) {
                    account.setMapActNo(platAccount.getActNo());
                    account.setMapChannelNo(platAccount.getChannelNo());
                }
            });
        }
        return bankAccounts;
    }
    
}
